You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tinkerpop.apache.org by sp...@apache.org on 2015/02/12 14:02:38 UTC

[72/77] incubator-tinkerpop git commit: replaced namespace com.tinkerpop with org.apache.tinkerpop

replaced namespace com.tinkerpop with org.apache.tinkerpop


Project: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/commit/f4da7f7a
Tree: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/tree/f4da7f7a
Diff: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/diff/f4da7f7a

Branch: refs/heads/master
Commit: f4da7f7a35800dcf1e7368e3eb65c9b9433f58c2
Parents: 4990f40
Author: Daniel Kuppitz <da...@hotmail.com>
Authored: Thu Feb 12 13:12:35 2015 +0100
Committer: Daniel Kuppitz <da...@hotmail.com>
Committed: Thu Feb 12 13:12:35 2015 +0100

----------------------------------------------------------------------
 bin/bump.sh                                     |   2 +-
 bin/clean-grapes.sh                             |   4 +-
 docs/preprocessor/processor.groovy              |  14 +-
 docs/src/gremlin-applications.asciidoc          |  66 +++---
 docs/src/implementations.asciidoc               |  56 ++---
 docs/src/intro.asciidoc                         |   2 +-
 docs/src/the-graph.asciidoc                     |  14 +-
 docs/src/the-graphcomputer.asciidoc             |  16 +-
 docs/src/the-traversal.asciidoc                 |  14 +-
 gremlin-algorithm/pom.xml                       |   4 +-
 .../algorithm/generator/AbstractGenerator.java  |   8 +-
 .../algorithm/generator/CommunityGenerator.java |  10 +-
 .../algorithm/generator/CopyDistribution.java   |   2 +-
 .../algorithm/generator/Distribution.java       |   2 +-
 .../generator/DistributionGenerator.java        |  10 +-
 .../gremlin/algorithm/generator/Generator.java  |   2 +-
 .../algorithm/generator/NormalDistribution.java |   2 +-
 .../generator/PowerLawDistribution.java         |   2 +-
 .../algorithm/generator/SizableIterable.java    |   2 +-
 gremlin-console/conf/remote-objects.yaml        |   2 +-
 gremlin-console/conf/remote.yaml                |   2 +-
 gremlin-console/pom.xml                         |  14 +-
 gremlin-console/src/assembly/standalone.xml     |   8 +-
 gremlin-console/src/main/bin/gremlin.bat        |   6 +-
 gremlin-console/src/main/bin/gremlin.sh         |   6 +-
 gremlin-console/src/main/ext/plugins.txt        |   6 +-
 .../tinkerpop/gremlin/console/Console.groovy    |  12 +-
 .../ConsoleImportCustomizerProvider.groovy      |   4 +-
 .../tinkerpop/gremlin/console/Mediator.groovy   |   6 +-
 .../console/commands/InstallCommand.groovy      |  12 +-
 .../console/commands/PluginCommand.groovy       |   4 +-
 .../console/commands/RemoteCommand.groovy       |   8 +-
 .../console/commands/SubmitCommand.groovy       |   4 +-
 .../console/commands/UninstallCommand.groovy    |   4 +-
 .../console/plugin/ConsolePluginAcceptor.groovy |   6 +-
 .../console/plugin/GephiRemoteAcceptor.groovy   |  16 +-
 .../gremlin/console/plugin/PluggedIn.groovy     |   4 +-
 .../gremlin/console/util/ArrayIterator.groovy   |   4 +-
 .../groovy/plugin/DriverGremlinPlugin.java      |  20 +-
 .../groovy/plugin/DriverRemoteAcceptor.java     |  18 +-
 .../groovy/plugin/GephiGremlinPlugin.java       |  14 +-
 .../groovy/plugin/UtilitiesGremlinPlugin.java   |  10 +-
 .../services/javax.script.ScriptEngineFactory   |   2 +-
 ...inkerpop.gremlin.groovy.plugin.GremlinPlugin |   6 +-
 .../plugin/UtilitiesGremlinPluginScript.groovy  |   6 +-
 .../AbstractGremlinServerIntegrationTest.java   |   6 +-
 .../groovy/plugin/DriverGremlinPluginTest.java  |   4 +-
 .../DriverRemoteAcceptorIntegrateTest.java      |  10 +-
 .../groovy/plugin/DriverRemoteAcceptorTest.java |   6 +-
 .../groovy/plugin/SpyPluginAcceptor.java        |   4 +-
 .../groovy/plugin/SugarGremlinPluginTest.java   |  12 +-
 .../plugin/UtilitiesGremlinPluginTest.java      |   6 +-
 .../plugin/gremlin-server-integration.yaml      |  10 +-
 .../gremlin/console/groovy/plugin/remote.yaml   |   2 +-
 .../groovy/plugin/tinkergraph-empty.properties  |   2 +-
 gremlin-core/pom.xml                            |   2 +-
 .../process/FastNoSuchElementException.java     |   2 +-
 .../apache/tinkerpop/gremlin/process/Path.java  |   4 +-
 .../apache/tinkerpop/gremlin/process/Scope.java |   2 +-
 .../apache/tinkerpop/gremlin/process/Step.java  |   8 +-
 .../org/apache/tinkerpop/gremlin/process/T.java |   8 +-
 .../tinkerpop/gremlin/process/Traversal.java    |  42 ++--
 .../gremlin/process/TraversalEngine.java        |   2 +-
 .../gremlin/process/TraversalSideEffects.java   |   8 +-
 .../gremlin/process/TraversalStrategies.java    |  24 +-
 .../gremlin/process/TraversalStrategy.java      |   2 +-
 .../tinkerpop/gremlin/process/Traverser.java    |   8 +-
 .../gremlin/process/TraverserGenerator.java     |   4 +-
 .../process/computer/ComputerResult.java        |   4 +-
 .../gremlin/process/computer/GraphComputer.java |   6 +-
 .../gremlin/process/computer/KeyValue.java      |   2 +-
 .../gremlin/process/computer/MapReduce.java     |  12 +-
 .../gremlin/process/computer/Memory.java        |   4 +-
 .../process/computer/MessageCombiner.java       |   2 +-
 .../gremlin/process/computer/MessageScope.java  |   8 +-
 .../gremlin/process/computer/Messenger.java     |   2 +-
 .../gremlin/process/computer/VertexProgram.java |   6 +-
 .../peerpressure/ClusterCountMapReduce.java     |  16 +-
 .../ClusterPopulationMapReduce.java             |  12 +-
 .../peerpressure/PeerPressureVertexProgram.java |  34 +--
 .../computer/lambda/LambdaMapReduce.java        |  20 +-
 .../computer/lambda/LambdaVertexProgram.java    |  24 +-
 .../ranking/pagerank/PageRankMapReduce.java     |  12 +-
 .../pagerank/PageRankMessageCombiner.java       |   4 +-
 .../ranking/pagerank/PageRankVertexProgram.java |  34 +--
 .../computer/traversal/TraversalScript.java     |  10 +-
 .../computer/traversal/TraversalSupplier.java   |   4 +-
 .../traversal/TraversalVertexProgram.java       |  62 +++---
 .../TraversalVertexProgramMessageCombiner.java  |   6 +-
 .../computer/traversal/TraverserExecutor.java   |  20 +-
 .../traversal/VertexTraversalSideEffects.java   |   8 +-
 .../traversal/step/map/ComputerResultStep.java  |  30 +--
 .../mapreduce/TraverserMapReduce.java           |  32 +--
 .../util/AbstractVertexProgramBuilder.java      |   4 +-
 .../computer/util/ComputerDataStrategy.java     |  22 +-
 .../computer/util/DefaultComputerResult.java    |  14 +-
 .../computer/util/GraphComputerHelper.java      |  14 +-
 .../process/computer/util/ImmutableMemory.java  |   6 +-
 .../process/computer/util/LambdaHolder.java     |   2 +-
 .../process/computer/util/MapMemory.java        |  12 +-
 .../process/computer/util/MemoryHelper.java     |   4 +-
 .../computer/util/ScriptEngineCache.java        |   4 +-
 .../computer/util/ScriptEngineLambda.java       |   4 +-
 .../process/computer/util/StaticMapReduce.java  |   6 +-
 .../computer/util/StaticVertexProgram.java      |   4 +-
 .../computer/util/VertexProgramHelper.java      |   8 +-
 .../graph/traversal/DefaultGraphTraversal.java  |   4 +-
 .../process/graph/traversal/EdgeTraversal.java  |   8 +-
 .../graph/traversal/ElementTraversal.java       |  26 +--
 .../process/graph/traversal/GraphTraversal.java | 206 ++++++++---------
 .../traversal/VertexPropertyTraversal.java      |   8 +-
 .../graph/traversal/VertexTraversal.java        |   8 +-
 .../gremlin/process/graph/traversal/__.java     |  24 +-
 .../graph/traversal/lambda/LoopTraversal.java   |   6 +-
 .../graph/traversal/step/ComparatorHolder.java  |   2 +-
 .../traversal/step/HasContainerHolder.java      |   4 +-
 .../process/graph/traversal/step/Ranging.java   |   2 +-
 .../graph/traversal/step/SideEffectCapable.java |   2 +-
 .../traversal/step/TraversalOptionParent.java   |   6 +-
 .../graph/traversal/step/branch/BranchStep.java |  16 +-
 .../graph/traversal/step/branch/ChooseStep.java |   6 +-
 .../graph/traversal/step/branch/LocalStep.java  |  16 +-
 .../graph/traversal/step/branch/RepeatStep.java |  20 +-
 .../graph/traversal/step/branch/UnionStep.java  |  10 +-
 .../graph/traversal/step/filter/AndStep.java    |   6 +-
 .../graph/traversal/step/filter/CoinStep.java   |  12 +-
 .../traversal/step/filter/ConjunctionStep.java  |  20 +-
 .../traversal/step/filter/CyclicPathStep.java   |  10 +-
 .../graph/traversal/step/filter/DedupStep.java  |  20 +-
 .../graph/traversal/step/filter/ExceptStep.java |  12 +-
 .../graph/traversal/step/filter/FilterStep.java |   8 +-
 .../graph/traversal/step/filter/HasStep.java    |  18 +-
 .../traversal/step/filter/HasTraversalStep.java |  16 +-
 .../graph/traversal/step/filter/IsStep.java     |  12 +-
 .../traversal/step/filter/LambdaFilterStep.java |   8 +-
 .../graph/traversal/step/filter/OrStep.java     |   6 +-
 .../graph/traversal/step/filter/RangeStep.java  |  16 +-
 .../graph/traversal/step/filter/RetainStep.java |  12 +-
 .../graph/traversal/step/filter/SampleStep.java |  22 +-
 .../traversal/step/filter/SimplePathStep.java   |  10 +-
 .../traversal/step/filter/TimeLimitStep.java    |  12 +-
 .../graph/traversal/step/filter/WhereStep.java  |  16 +-
 .../graph/traversal/step/map/BackStep.java      |  14 +-
 .../graph/traversal/step/map/CoalesceStep.java  |  14 +-
 .../graph/traversal/step/map/CountStep.java     |  14 +-
 .../traversal/step/map/EdgeOtherVertexStep.java |  16 +-
 .../traversal/step/map/EdgeVertexStep.java      |  18 +-
 .../graph/traversal/step/map/FlatMapStep.java   |  10 +-
 .../graph/traversal/step/map/FoldStep.java      |  14 +-
 .../graph/traversal/step/map/IdStep.java        |  10 +-
 .../graph/traversal/step/map/KeyStep.java       |  10 +-
 .../graph/traversal/step/map/LabelStep.java     |  10 +-
 .../traversal/step/map/LambdaFlatMapStep.java   |   8 +-
 .../graph/traversal/step/map/LambdaMapStep.java |   8 +-
 .../graph/traversal/step/map/MapStep.java       |  10 +-
 .../graph/traversal/step/map/MaxStep.java       |  14 +-
 .../graph/traversal/step/map/MeanStep.java      |  16 +-
 .../graph/traversal/step/map/MinStep.java       |  14 +-
 .../traversal/step/map/OrderGlobalStep.java     |  20 +-
 .../traversal/step/map/OrderLocalStep.java      |  14 +-
 .../graph/traversal/step/map/PathStep.java      |  20 +-
 .../traversal/step/map/PropertiesStep.java      |  16 +-
 .../traversal/step/map/PropertyElementStep.java |  12 +-
 .../traversal/step/map/PropertyMapStep.java     |  22 +-
 .../traversal/step/map/PropertyValueStep.java   |  10 +-
 .../graph/traversal/step/map/SackStep.java      |   8 +-
 .../graph/traversal/step/map/SelectOneStep.java |  24 +-
 .../graph/traversal/step/map/SelectStep.java    |  26 +--
 .../graph/traversal/step/map/SumStep.java       |  14 +-
 .../graph/traversal/step/map/UnfoldStep.java    |  10 +-
 .../graph/traversal/step/map/VertexStep.java    |  18 +-
 .../traversal/step/map/match/Bindings.java      |   2 +-
 .../step/map/match/CrossJoinEnumerator.java     |   2 +-
 .../traversal/step/map/match/Enumerator.java    |   2 +-
 .../step/map/match/InnerJoinEnumerator.java     |   2 +-
 .../step/map/match/IteratorEnumerator.java      |   2 +-
 .../traversal/step/map/match/MatchStep.java     |  22 +-
 .../step/map/match/SerialEnumerator.java        |   2 +-
 .../step/map/match/SimpleEnumerator.java        |   2 +-
 .../traversal/step/sideEffect/AddEdgeStep.java  |  16 +-
 .../step/sideEffect/AggregateStep.java          |  32 +--
 .../traversal/step/sideEffect/GraphStep.java    |  22 +-
 .../step/sideEffect/GroupCountStep.java         |  32 +--
 .../traversal/step/sideEffect/GroupStep.java    |  38 ++--
 .../traversal/step/sideEffect/IdentityStep.java |   8 +-
 .../traversal/step/sideEffect/InjectStep.java   |   6 +-
 .../step/sideEffect/LambdaSideEffectStep.java   |   8 +-
 .../traversal/step/sideEffect/ProfileStep.java  |  24 +-
 .../step/sideEffect/SackElementValueStep.java   |  12 +-
 .../step/sideEffect/SackObjectStep.java         |   8 +-
 .../step/sideEffect/SideEffectCapStep.java      |  14 +-
 .../step/sideEffect/SideEffectStep.java         |  10 +-
 .../traversal/step/sideEffect/StartStep.java    |  12 +-
 .../traversal/step/sideEffect/StoreStep.java    |  30 +--
 .../traversal/step/sideEffect/SubgraphStep.java |  26 +--
 .../traversal/step/sideEffect/TreeStep.java     |  34 +--
 .../mapreduce/AggregateMapReduce.java           |  18 +-
 .../mapreduce/GroupCountMapReduce.java          |  16 +-
 .../sideEffect/mapreduce/GroupMapReduce.java    |  26 +--
 .../sideEffect/mapreduce/ProfileMapReduce.java  |  16 +-
 .../sideEffect/mapreduce/StoreMapReduce.java    |  18 +-
 .../sideEffect/mapreduce/TreeMapReduce.java     |  14 +-
 .../step/util/CollectingBarrierStep.java        |  12 +-
 .../traversal/step/util/ComputerAwareStep.java  |  18 +-
 .../traversal/step/util/MarkerIdentityStep.java |   8 +-
 .../traversal/step/util/PathIdentityStep.java   |  10 +-
 .../step/util/ReducingBarrierStep.java          |  18 +-
 .../step/util/SupplyingBarrierStep.java         |  12 +-
 .../strategy/AbstractTraversalStrategy.java     |   6 +-
 .../ComparatorHolderRemovalStrategy.java        |  12 +-
 .../traversal/strategy/ConjunctionStrategy.java |  24 +-
 .../strategy/DedupOptimizerStrategy.java        |  18 +-
 .../strategy/EngineDependentStrategy.java       |  10 +-
 .../strategy/IdentityRemovalStrategy.java       |  10 +-
 .../strategy/LabeledEndStepStrategy.java        |  10 +-
 .../traversal/strategy/MatchWhereStrategy.java  |  22 +-
 .../traversal/strategy/ProfileStrategy.java     |  14 +-
 .../strategy/RangeByIsCountStrategy.java        |  22 +-
 .../traversal/strategy/ReducingStrategy.java    |  16 +-
 .../strategy/SideEffectCapStrategy.java         |  16 +-
 .../SideEffectRegistrationStrategy.java         |  12 +-
 .../strategy/TraversalVerificationStrategy.java |  20 +-
 .../traversal/util/EmptyGraphTraversal.java     |  10 +-
 .../process/graph/util/HasContainer.java        |  16 +-
 .../gremlin/process/graph/util/Tree.java        |   2 +-
 .../process/traversal/DefaultTraversal.java     |  10 +-
 .../traversal/DefaultTraversalSideEffects.java  |  12 +-
 .../traversal/DefaultTraversalStrategies.java   |  16 +-
 .../gremlin/process/traversal/StepPosition.java |   2 +-
 .../process/traversal/TraversalMatrix.java      |  10 +-
 .../lambda/AbstractLambdaTraversal.java         |  28 +--
 .../traversal/lambda/ConstantTraversal.java     |   2 +-
 .../traversal/lambda/ElementValueTraversal.java |   6 +-
 .../traversal/lambda/FilterTraversal.java       |   4 +-
 .../lambda/FilterTraverserTraversal.java        |   4 +-
 .../traversal/lambda/HasNextTraversal.java      |  20 +-
 .../traversal/lambda/IdentityTraversal.java     |   4 +-
 .../process/traversal/lambda/MapTraversal.java  |   4 +-
 .../traversal/lambda/MapTraverserTraversal.java |   4 +-
 .../process/traversal/lambda/TrueTraversal.java |   2 +-
 .../process/traversal/step/AbstractStep.java    |  10 +-
 .../step/ElementFunctionComparator.java         |   4 +-
 .../traversal/step/ElementValueComparator.java  |   4 +-
 .../process/traversal/step/EmptyStep.java       |  16 +-
 .../process/traversal/step/EngineDependent.java |   4 +-
 .../traversal/step/ExpandableStepIterator.java  |  10 +-
 .../process/traversal/step/MapReducer.java      |   4 +-
 .../process/traversal/step/Reducing.java        |   2 +-
 .../process/traversal/step/Reversible.java      |   2 +-
 .../traversal/step/SideEffectRegistrar.java     |   2 +-
 .../process/traversal/step/TraversalParent.java |  10 +-
 .../process/traversal/util/EmptyTraversal.java  |  28 +--
 .../util/EmptyTraversalSideEffects.java         |   6 +-
 .../util/EmptyTraversalStrategies.java          |  14 +-
 .../traversal/util/SideEffectHelper.java        |   4 +-
 .../process/traversal/util/TraversalHelper.java |  24 +-
 .../process/traversal/util/TraversalRing.java   |   6 +-
 .../process/traversal/util/TraversalUtil.java   |   6 +-
 .../traverser/B_O_PA_S_SE_SL_Traverser.java     |  16 +-
 .../B_O_PA_S_SE_SL_TraverserGenerator.java      |   8 +-
 .../traverser/B_O_P_PA_S_SE_SL_Traverser.java   |   8 +-
 .../B_O_P_PA_S_SE_SL_TraverserGenerator.java    |   8 +-
 .../process/traverser/B_O_Traverser.java        |   4 +-
 .../traverser/B_O_TraverserGenerator.java       |   8 +-
 .../gremlin/process/traverser/O_Traverser.java  |   4 +-
 .../process/traverser/O_TraverserGenerator.java |   8 +-
 .../traverser/TraverserGeneratorFactory.java    |   6 +-
 .../process/traverser/TraverserRequirement.java |   6 +-
 .../traverser/util/AbstractPathTraverser.java   |  20 +-
 .../traverser/util/AbstractTraverser.java       |  24 +-
 .../util/DefaultTraverserGeneratorFactory.java  |  18 +-
 .../process/traverser/util/EmptyTraverser.java  |  16 +-
 .../tinkerpop/gremlin/process/util/BulkSet.java |   2 +-
 .../gremlin/process/util/MapHelper.java         |   2 +-
 .../gremlin/process/util/TraverserSet.java      |   4 +-
 .../process/util/metric/ImmutableMetrics.java   |   2 +-
 .../gremlin/process/util/metric/Metrics.java    |   2 +-
 .../process/util/metric/MutableMetrics.java     |   2 +-
 .../util/metric/StandardTraversalMetrics.java   |   2 +-
 .../process/util/metric/TraversalMetrics.java   |   6 +-
 .../gremlin/process/util/path/EmptyPath.java    |   4 +-
 .../process/util/path/ImmutablePath.java        |   4 +-
 .../gremlin/process/util/path/MutablePath.java  |   4 +-
 .../gremlin/process/util/path/SparsePath.java   |   4 +-
 .../tinkerpop/gremlin/structure/Compare.java    |   2 +-
 .../tinkerpop/gremlin/structure/Contains.java   |   2 +-
 .../tinkerpop/gremlin/structure/Direction.java  |   2 +-
 .../tinkerpop/gremlin/structure/Edge.java       |   6 +-
 .../tinkerpop/gremlin/structure/Element.java    |   8 +-
 .../tinkerpop/gremlin/structure/Graph.java      | 114 +++++-----
 .../tinkerpop/gremlin/structure/Operator.java   |   2 +-
 .../tinkerpop/gremlin/structure/Order.java      |   2 +-
 .../tinkerpop/gremlin/structure/Property.java   |   4 +-
 .../gremlin/structure/PropertyType.java         |   2 +-
 .../gremlin/structure/Transaction.java          |   4 +-
 .../tinkerpop/gremlin/structure/Vertex.java     |   8 +-
 .../gremlin/structure/VertexProperty.java       |   8 +-
 .../gremlin/structure/io/DefaultIo.java         |   4 +-
 .../gremlin/structure/io/GraphMigrator.java     |  10 +-
 .../gremlin/structure/io/GraphReader.java       |  16 +-
 .../gremlin/structure/io/GraphWriter.java       |  12 +-
 .../tinkerpop/gremlin/structure/io/Mapper.java  |   2 +-
 .../structure/io/graphml/GraphMLReader.java     |  26 +--
 .../structure/io/graphml/GraphMLTokens.java     |   2 +-
 .../structure/io/graphml/GraphMLWriter.java     |  18 +-
 .../io/graphml/GraphMLWriterHelper.java         |   2 +-
 .../structure/io/graphson/GraphSONGraph.java    |   8 +-
 .../structure/io/graphson/GraphSONMapper.java   |   6 +-
 .../structure/io/graphson/GraphSONModule.java   |  14 +-
 .../structure/io/graphson/GraphSONReader.java   |  30 +--
 .../io/graphson/GraphSONSerializerProvider.java |   2 +-
 .../structure/io/graphson/GraphSONTokens.java   |   2 +-
 .../structure/io/graphson/GraphSONVertex.java   |  10 +-
 .../io/graphson/GraphSONVertexProperty.java     |  10 +-
 .../structure/io/graphson/GraphSONWriter.java   |  16 +-
 .../io/graphson/LegacyGraphSONReader.java       |  20 +-
 .../structure/io/kryo/EdgeTerminator.java       |   2 +-
 .../structure/io/kryo/EntrySerializer.java      |   2 +-
 .../structure/io/kryo/GraphSerializer.java      |  26 +--
 .../structure/io/kryo/GremlinClassResolver.java |  22 +-
 .../gremlin/structure/io/kryo/KryoMapper.java   |  52 ++---
 .../gremlin/structure/io/kryo/KryoReader.java   |  18 +-
 .../gremlin/structure/io/kryo/KryoWriter.java   |  16 +-
 .../structure/io/kryo/URISerializer.java        |   2 +-
 .../structure/io/kryo/UUIDSerializer.java       |   2 +-
 .../io/kryo/VertexByteArrayInputStream.java     |   6 +-
 .../structure/io/kryo/VertexTerminator.java     |   2 +-
 .../gremlin/structure/server/ClusterAware.java  |   2 +-
 .../structure/server/IntervalVertexRange.java   |   2 +-
 .../gremlin/structure/server/Partition.java     |   2 +-
 .../gremlin/structure/server/VertexRange.java   |   2 +-
 .../structure/strategy/GraphStrategy.java       | 222 +++++++++----------
 .../gremlin/structure/strategy/IdStrategy.java  |  26 +--
 .../structure/strategy/IdentityStrategy.java    |   4 +-
 .../structure/strategy/PartitionStrategy.java   |  48 ++--
 .../structure/strategy/ReadOnlyStrategy.java    |  16 +-
 .../structure/strategy/SequenceStrategy.java    |  20 +-
 .../structure/strategy/StrategyContext.java     |   6 +-
 .../structure/strategy/StrategyEdge.java        |  20 +-
 .../structure/strategy/StrategyElement.java     |   6 +-
 .../structure/strategy/StrategyGraph.java       |  32 +--
 .../structure/strategy/StrategyProperty.java    |  16 +-
 .../structure/strategy/StrategyVariables.java   |   8 +-
 .../structure/strategy/StrategyVertex.java      |  20 +-
 .../strategy/StrategyVertexProperty.java        |  18 +-
 .../structure/strategy/StrategyWrapped.java     |   2 +-
 .../structure/strategy/SubgraphStrategy.java    |  20 +-
 .../step/sideEffect/StrategyGraphStep.java      |  18 +-
 .../gremlin/structure/util/Comparators.java     |  10 +-
 .../gremlin/structure/util/ElementHelper.java   |  68 +++---
 .../structure/util/FeatureDescriptor.java       |   2 +-
 .../gremlin/structure/util/GraphFactory.java    |  24 +-
 .../structure/util/GraphVariableHelper.java     |   4 +-
 .../gremlin/structure/util/StringFactory.java   |  52 ++---
 .../structure/util/batch/BatchFeatures.java     |   4 +-
 .../structure/util/batch/BatchGraph.java        |  48 ++--
 .../gremlin/structure/util/batch/Exists.java    |   8 +-
 .../structure/util/batch/VertexIdType.java      |  12 +-
 .../util/batch/cache/AbstractIDVertexCache.java |   4 +-
 .../util/batch/cache/LongIDVertexCache.java     |   4 +-
 .../util/batch/cache/ObjectIDVertexCache.java   |   2 +-
 .../util/batch/cache/StringCompression.java     |   2 +-
 .../util/batch/cache/StringIDVertexCache.java   |   4 +-
 .../util/batch/cache/URLCompression.java        |   2 +-
 .../structure/util/batch/cache/VertexCache.java |   4 +-
 .../structure/util/detached/Attachable.java     |   6 +-
 .../structure/util/detached/DetachedEdge.java   |  24 +-
 .../util/detached/DetachedElement.java          |  10 +-
 .../util/detached/DetachedFactory.java          |  14 +-
 .../structure/util/detached/DetachedPath.java   |  14 +-
 .../util/detached/DetachedProperty.java         |  16 +-
 .../structure/util/detached/DetachedVertex.java |  22 +-
 .../util/detached/DetachedVertexProperty.java   |  18 +-
 .../structure/util/empty/EmptyGraph.java        |  22 +-
 .../structure/util/empty/EmptyProperty.java     |   8 +-
 .../util/empty/EmptyVertexProperty.java         |  12 +-
 .../structure/util/wrapped/WrappedEdge.java     |   2 +-
 .../structure/util/wrapped/WrappedElement.java  |   2 +-
 .../structure/util/wrapped/WrappedGraph.java    |   2 +-
 .../structure/util/wrapped/WrappedProperty.java |   2 +-
 .../util/wrapped/WrappedVariables.java          |   2 +-
 .../structure/util/wrapped/WrappedVertex.java   |   2 +-
 .../util/wrapped/WrappedVertexProperty.java     |   2 +-
 .../apache/tinkerpop/gremlin/util/Gremlin.java  |   2 +-
 .../tinkerpop/gremlin/util/Serializer.java      |   2 +-
 .../tinkerpop/gremlin/util/StreamFactory.java   |   2 +-
 .../apache/tinkerpop/gremlin/util/TimeUtil.java |   2 +-
 .../gremlin/util/config/YamlConfiguration.java  |   2 +-
 .../util/function/ArrayListSupplier.java        |   2 +-
 .../gremlin/util/function/BulkSetSupplier.java  |   4 +-
 .../util/function/CloningUnaryOperator.java     |   2 +-
 .../gremlin/util/function/ConstantSupplier.java |   2 +-
 .../gremlin/util/function/FunctionUtils.java    |   2 +-
 .../gremlin/util/function/HashMapSupplier.java  |   2 +-
 .../gremlin/util/function/HashSetSupplier.java  |   2 +-
 .../util/function/MeanNumberSupplier.java       |   4 +-
 .../util/function/ThrowingBiConsumer.java       |   2 +-
 .../gremlin/util/function/ThrowingConsumer.java |   2 +-
 .../gremlin/util/function/ThrowingFunction.java |   2 +-
 .../gremlin/util/function/ThrowingSupplier.java |   2 +-
 .../util/function/TraversableLambda.java        |   4 +-
 .../gremlin/util/function/TreeSupplier.java     |   4 +-
 .../gremlin/util/function/TriConsumer.java      |   2 +-
 .../gremlin/util/function/TriFunction.java      |   2 +-
 .../gremlin/util/iterator/ArrayIterator.java    |   4 +-
 .../gremlin/util/iterator/DoubleIterator.java   |   4 +-
 .../gremlin/util/iterator/EmptyIterator.java    |   4 +-
 .../gremlin/util/iterator/IteratorUtils.java    |   4 +-
 .../gremlin/util/iterator/MultiIterator.java    |   4 +-
 .../gremlin/util/iterator/SingleIterator.java   |   4 +-
 .../tinkerpop/gremlin/util/tools/MultiMap.java  |   2 +-
 .../tinkerpop/gremlin/util/tools/TimeUtils.java |   2 +-
 gremlin-driver/pom.xml                          |   6 +-
 .../tinkerpop/gremlin/driver/Channelizer.java   |  12 +-
 .../apache/tinkerpop/gremlin/driver/Client.java |  10 +-
 .../tinkerpop/gremlin/driver/Cluster.java       |   4 +-
 .../tinkerpop/gremlin/driver/ClusterInfo.java   |   2 +-
 .../tinkerpop/gremlin/driver/Connection.java    |   8 +-
 .../gremlin/driver/ConnectionPool.java          |   6 +-
 .../tinkerpop/gremlin/driver/Handler.java       |   8 +-
 .../apache/tinkerpop/gremlin/driver/Host.java   |   2 +-
 .../gremlin/driver/LoadBalancingStrategy.java   |   4 +-
 .../gremlin/driver/MessageSerializer.java       |  14 +-
 .../tinkerpop/gremlin/driver/ResponseQueue.java |   6 +-
 .../apache/tinkerpop/gremlin/driver/Result.java |  10 +-
 .../tinkerpop/gremlin/driver/ResultSet.java     |   6 +-
 .../tinkerpop/gremlin/driver/Settings.java      |   4 +-
 .../apache/tinkerpop/gremlin/driver/Tokens.java |   2 +-
 .../driver/exception/ConnectionException.java   |   2 +-
 .../driver/exception/ResponseException.java     |   4 +-
 .../handler/NioGremlinRequestEncoder.java       |   8 +-
 .../handler/NioGremlinResponseDecoder.java      |   4 +-
 .../driver/handler/WebSocketClientHandler.java  |   2 +-
 .../handler/WebSocketGremlinRequestEncoder.java |   8 +-
 .../WebSocketGremlinResponseDecoder.java        |   6 +-
 .../gremlin/driver/message/RequestMessage.java  |   4 +-
 .../gremlin/driver/message/ResponseMessage.java |   2 +-
 .../gremlin/driver/message/ResponseResult.java  |   2 +-
 .../gremlin/driver/message/ResponseStatus.java  |   2 +-
 .../driver/message/ResponseStatusCode.java      |   4 +-
 .../ser/AbstractJsonMessageSerializerV1d0.java  |  14 +-
 .../driver/ser/JsonBuilderKryoSerializer.java   |   2 +-
 .../ser/JsonMessageSerializerGremlinV1d0.java   |   4 +-
 .../driver/ser/JsonMessageSerializerV1d0.java   |  10 +-
 .../driver/ser/KryoMessageSerializerV1d0.java   |  18 +-
 .../driver/ser/MessageTextSerializer.java       |   8 +-
 .../tinkerpop/gremlin/driver/ser/SerTokens.java |   2 +-
 .../driver/ser/SerializationException.java      |   2 +-
 .../gremlin/driver/ser/Serializers.java         |   8 +-
 .../gremlin/driver/simple/NioClient.java        |  14 +-
 .../gremlin/driver/simple/SimpleClient.java     |   8 +-
 .../gremlin/driver/simple/WebSocketClient.java  |  16 +-
 .../tinkerpop/gremlin/driver/HostTest.java      |   2 +-
 .../gremlin/driver/RequestMessageTest.java      |   4 +-
 .../tinkerpop/gremlin/driver/ResultTest.java    |  16 +-
 .../driver/benchmark/ProfilingApplication.java  |   6 +-
 .../JsonMessageSerializerGremlinV1d0Test.java   |  26 +--
 .../ser/JsonMessageSerializerV1d0Test.java      |  26 +--
 .../ser/KryoMessageSerializerV1d0Test.java      |  30 +--
 gremlin-groovy-test/pom.xml                     |   6 +-
 .../groovy/loaders/GremlinLoaderTest.groovy     |   4 +-
 .../groovy/loaders/SugarLoaderTest.groovy       |  12 +-
 .../gremlin/groovy/util/SugarTestHelper.groovy  |   4 +-
 .../gremlin/process/ComputerTestHelper.groovy   |  10 +-
 .../computer/GroovyGraphComputerTest.groovy     |   8 +-
 .../step/branch/GroovyBranchTest.groovy         |  14 +-
 .../step/branch/GroovyChooseTest.groovy         |  10 +-
 .../step/branch/GroovyLocalTest.groovy          |  18 +-
 .../step/branch/GroovyRepeatTest.groovy         |  18 +-
 .../step/branch/GroovyUnionTest.groovy          |  14 +-
 .../traversal/step/filter/GroovyAndTest.groovy  |  24 +-
 .../traversal/step/filter/GroovyCoinTest.groovy |  10 +-
 .../step/filter/GroovyCyclicPathTest.groovy     |  12 +-
 .../step/filter/GroovyDedupTest.groovy          |  14 +-
 .../step/filter/GroovyExceptTest.groovy         |  16 +-
 .../step/filter/GroovyFilterTest.groovy         |  12 +-
 .../step/filter/GroovyHasNotTest.groovy         |  10 +-
 .../traversal/step/filter/GroovyHasTest.groovy  |  22 +-
 .../traversal/step/filter/GroovyIsTest.groovy   |  14 +-
 .../traversal/step/filter/GroovyOrTest.groovy   |  24 +-
 .../step/filter/GroovyRangeTest.groovy          |  12 +-
 .../step/filter/GroovyRetainTest.groovy         |  10 +-
 .../step/filter/GroovySampleTest.groovy         |  14 +-
 .../step/filter/GroovySimplePathTest.groovy     |  16 +-
 .../step/filter/GroovyWhereTest.groovy          |  14 +-
 .../traversal/step/map/GroovyBackTest.groovy    |  16 +-
 .../step/map/GroovyCoalesceTest.groovy          |  16 +-
 .../traversal/step/map/GroovyCountTest.groovy   |  12 +-
 .../traversal/step/map/GroovyFoldTest.groovy    |  10 +-
 .../traversal/step/map/GroovyMapTest.groovy     |  10 +-
 .../traversal/step/map/GroovyMatchTest.groovy   |  16 +-
 .../traversal/step/map/GroovyMaxTest.groovy     |  12 +-
 .../traversal/step/map/GroovyMeanTest.groovy    |  10 +-
 .../traversal/step/map/GroovyMinTest.groovy     |  12 +-
 .../traversal/step/map/GroovyOrderTest.groovy   |  16 +-
 .../traversal/step/map/GroovyPathTest.groovy    |  14 +-
 .../step/map/GroovyPropertiesTest.groovy        |  10 +-
 .../traversal/step/map/GroovySelectTest.groovy  |  12 +-
 .../traversal/step/map/GroovyUnfoldTest.groovy  |  12 +-
 .../step/map/GroovyValueMapTest.groovy          |  10 +-
 .../traversal/step/map/GroovyVertexTest.groovy  |  18 +-
 .../step/sideEffect/GroovyAddEdgeTest.groovy    |   8 +-
 .../step/sideEffect/GroovyAggregateTest.groovy  |  12 +-
 .../step/sideEffect/GroovyGroupCountTest.groovy |  12 +-
 .../step/sideEffect/GroovyGroupTest.groovy      |  10 +-
 .../step/sideEffect/GroovyInjectTest.groovy     |  10 +-
 .../step/sideEffect/GroovyProfileTest.groovy    |  16 +-
 .../step/sideEffect/GroovySackTest.groovy       |  12 +-
 .../sideEffect/GroovySideEffectCapTest.groovy   |  14 +-
 .../step/sideEffect/GroovySideEffectTest.groovy |   8 +-
 .../step/sideEffect/GroovyStoreTest.groovy      |  12 +-
 .../step/sideEffect/GroovySubgraphTest.groovy   |  12 +-
 .../step/sideEffect/GroovyTreeTest.groovy       |  14 +-
 .../groovy/GroovyEnvironmentIntegrateSuite.java |  14 +-
 .../GroovyEnvironmentPerformanceSuite.java      |  14 +-
 .../gremlin/groovy/GroovyEnvironmentSuite.java  |  22 +-
 .../engine/GremlinExecutorPerformanceTest.java  |  14 +-
 .../groovy/engine/GremlinExecutorTest.java      |  12 +-
 .../engine/GroovyTraversalScriptTest.java       |   8 +-
 .../GremlinGroovyScriptEngineIntegrateTest.java |   8 +-
 .../jsr223/GremlinGroovyScriptEngineTest.java   |  30 +--
 .../process/GroovyProcessComputerSuite.java     |  22 +-
 .../process/GroovyProcessStandardSuite.java     |  20 +-
 .../META-INF/javax.script.ScriptEngineFactory   |   2 +-
 .../services/javax.script.ScriptEngineFactory   |   2 +-
 .../DefaultImportCustomizerProviderTest.java    |   4 +-
 gremlin-groovy/pom.xml                          |   6 +-
 .../gremlin/groovy/loaders/GremlinLoader.groovy |  18 +-
 .../gremlin/groovy/loaders/ObjectLoader.groovy  |   2 +-
 .../gremlin/groovy/loaders/StepLoader.groovy    |  12 +-
 .../gremlin/groovy/loaders/SugarLoader.groovy   |  16 +-
 .../groovy/util/DependencyGrabber.groovy        |   4 +-
 .../gremlin/groovy/util/MetaRegistryUtil.groovy |   2 +-
 .../AbstractImportCustomizerProvider.java       |  70 +++---
 .../groovy/CompilerCustomizerProvider.java      |   2 +-
 .../groovy/DefaultImportCustomizerProvider.java |   2 +-
 .../groovy/EmptyImportCustomizerProvider.java   |   4 +-
 .../groovy/ImportCustomizerProvider.java        |   2 +-
 .../groovy/NoImportCustomizerProvider.java      |   2 +-
 .../groovy/SecurityCustomizerProvider.java      |   2 +-
 .../gremlin/groovy/engine/GremlinExecutor.java  |  12 +-
 .../groovy/engine/GroovyTraversalScript.java    |  26 +--
 .../gremlin/groovy/engine/ScriptEngines.java    |  18 +-
 .../gremlin/groovy/function/GComparator.java    |   2 +-
 .../gremlin/groovy/function/GFunction.java      |   2 +-
 .../gremlin/groovy/function/GSupplier.java      |   2 +-
 .../gremlin/groovy/function/GUnaryOperator.java |   2 +-
 .../groovy/jsr223/DependencyManager.java        |  16 +-
 .../groovy/jsr223/GremlinGroovyClassLoader.java |   2 +-
 .../jsr223/GremlinGroovyScriptEngine.java       |  20 +-
 .../GremlinGroovyScriptEngineFactory.java       |   4 +-
 .../jsr223/ManagedConcurrentValueMap.java       |   2 +-
 .../jsr223/ScriptEnginePluginAcceptor.java      |   6 +-
 .../gremlin/groovy/jsr223/ScriptExecutor.java   |   2 +-
 .../groovy/plugin/AbstractGremlinPlugin.java    |   4 +-
 .../gremlin/groovy/plugin/Artifact.java         |   2 +-
 .../gremlin/groovy/plugin/GremlinPlugin.java    |   4 +-
 .../groovy/plugin/GremlinPluginException.java   |   2 +-
 .../plugin/IllegalEnvironmentException.java     |   2 +-
 .../gremlin/groovy/plugin/PluginAcceptor.java   |   2 +-
 .../plugin/PluginInitializationException.java   |   2 +-
 .../gremlin/groovy/plugin/RemoteAcceptor.java   |   8 +-
 .../gremlin/groovy/plugin/RemoteException.java  |   4 +-
 .../groovy/plugin/SugarGremlinPlugin.java       |   4 +-
 ...inkerpop.gremlin.groovy.plugin.GremlinPlugin |   2 +-
 gremlin-server/conf/gremlin-server-classic.yaml |   4 +-
 gremlin-server/conf/gremlin-server-min.yaml     |   4 +-
 gremlin-server/conf/gremlin-server-modern.yaml  |   4 +-
 gremlin-server/conf/gremlin-server-neo4j.yaml   |  10 +-
 .../conf/gremlin-server-rest-modern.yaml        |   6 +-
 gremlin-server/conf/gremlin-server.yaml         |  12 +-
 gremlin-server/conf/log4j-server.properties     |   4 +-
 gremlin-server/conf/neo4j-empty.properties      |   2 +-
 .../conf/tinkergraph-empty.properties           |   2 +-
 gremlin-server/pom.xml                          |  14 +-
 gremlin-server/src/main/bin/gremlin-server.bat  |   4 +-
 gremlin-server/src/main/bin/gremlin-server.sh   |   4 +-
 .../gremlin/server/AbstractChannelizer.java     |  16 +-
 .../tinkerpop/gremlin/server/Channelizer.java   |   6 +-
 .../tinkerpop/gremlin/server/Context.java       |   8 +-
 .../apache/tinkerpop/gremlin/server/Graphs.java |  10 +-
 .../tinkerpop/gremlin/server/GremlinServer.java |   8 +-
 .../tinkerpop/gremlin/server/OpProcessor.java   |   6 +-
 .../tinkerpop/gremlin/server/Settings.java      |  10 +-
 .../gremlin/server/channel/HttpChannelizer.java |  14 +-
 .../gremlin/server/channel/NioChannelizer.java  |  16 +-
 .../server/channel/WebSocketChannelizer.java    |  18 +-
 .../handler/HttpGremlinEndpointHandler.java     |  22 +-
 .../gremlin/server/handler/IteratorHandler.java |  12 +-
 .../handler/NioGremlinBinaryRequestDecoder.java |  10 +-
 .../handler/NioGremlinResponseEncoder.java      |  14 +-
 .../server/handler/OpExecutorHandler.java       |  16 +-
 .../server/handler/OpSelectorHandler.java       |  26 +--
 .../gremlin/server/handler/StateKey.java        |   6 +-
 .../handler/WsGremlinBinaryRequestDecoder.java  |  10 +-
 .../handler/WsGremlinResponseEncoder.java       |  16 +-
 .../handler/WsGremlinTextRequestDecoder.java    |  10 +-
 .../server/op/AbstractEvalOpProcessor.java      |  30 +--
 .../tinkerpop/gremlin/server/op/OpLoader.java   |   6 +-
 .../gremlin/server/op/OpProcessorException.java |   4 +-
 .../server/op/control/ControlOpProcessor.java   |  22 +-
 .../gremlin/server/op/control/ControlOps.java   |  18 +-
 .../gremlin/server/op/session/Session.java      |  10 +-
 .../server/op/session/SessionOpProcessor.java   |  22 +-
 .../gremlin/server/op/session/SessionOps.java   |  18 +-
 .../server/op/standard/StandardOpProcessor.java |  10 +-
 .../gremlin/server/op/standard/StandardOps.java |  12 +-
 .../server/util/GremlinServerInstall.java       |   6 +-
 .../gremlin/server/util/MetricManager.java      |   2 +-
 ....apache.tinkerpop.gremlin.server.OpProcessor |   6 +-
 .../AbstractGremlinServerIntegrationTest.java   |   2 +-
 .../AbstractGremlinServerPerformanceTest.java   |   2 +-
 .../tinkerpop/gremlin/server/GraphsTest.java    |   6 +-
 .../server/GremlinAdditionPerformanceTest.java  |  10 +-
 .../server/GremlinDriverIntegrateTest.java      |  28 +--
 .../server/GremlinServerHttpIntegrateTest.java  |   4 +-
 .../server/GremlinServerIntegrateTest.java      |  34 +--
 .../server/GremlinTraversalPerformanceTest.java |   8 +-
 .../server/gremlin-server-integration.yaml      |  10 +-
 .../server/gremlin-server-performance.yaml      |   8 +-
 .../GremlinServerAdditionSimulation.scala       |   4 +-
 gremlin-test/pom.xml                            |   6 +-
 .../gremlin/AbstractGraphProvider.java          |  10 +-
 .../tinkerpop/gremlin/AbstractGremlinSuite.java |  16 +-
 .../tinkerpop/gremlin/AbstractGremlinTest.java  |  18 +-
 .../tinkerpop/gremlin/ExceptionCoverage.java    |   2 +-
 .../tinkerpop/gremlin/ExceptionCoverageSet.java |   2 +-
 .../tinkerpop/gremlin/FeatureRequirement.java   |   4 +-
 .../gremlin/FeatureRequirementSet.java          |   8 +-
 .../tinkerpop/gremlin/FeatureRequirements.java  |   2 +-
 .../apache/tinkerpop/gremlin/GraphManager.java  |   2 +-
 .../apache/tinkerpop/gremlin/GraphProvider.java |  68 +++---
 .../apache/tinkerpop/gremlin/LoadGraphWith.java |  20 +-
 .../apache/tinkerpop/gremlin/TestHelper.java    |   2 +-
 .../generator/AbstractGeneratorTest.java        |  10 +-
 .../generator/CommunityGeneratorTest.java       |  16 +-
 .../generator/DistributionGeneratorTest.java    |  16 +-
 .../process/AbstractGremlinProcessTest.java     |   6 +-
 .../gremlin/process/ProcessComputerSuite.java   |  32 +--
 .../process/ProcessPerformanceSuite.java        |  16 +-
 .../gremlin/process/ProcessStandardSuite.java   |  40 ++--
 .../process/TraversalPerformanceTest.java       |   8 +-
 .../process/computer/GraphComputerTest.java     |  28 +--
 .../ranking/PageRankVertexProgramTest.java      |  14 +-
 .../computer/util/ComputerDataStrategyTest.java |  14 +-
 .../graph/traversal/step/branch/BranchTest.java |  16 +-
 .../graph/traversal/step/branch/ChooseTest.java |  16 +-
 .../graph/traversal/step/branch/LocalTest.java  |  24 +-
 .../graph/traversal/step/branch/RepeatTest.java |  22 +-
 .../graph/traversal/step/branch/UnionTest.java  |  14 +-
 .../graph/traversal/step/filter/AndTest.java    |  24 +-
 .../graph/traversal/step/filter/CoinTest.java   |  12 +-
 .../traversal/step/filter/CyclicPathTest.java   |  14 +-
 .../graph/traversal/step/filter/DedupTest.java  |  18 +-
 .../graph/traversal/step/filter/ExceptTest.java |  22 +-
 .../graph/traversal/step/filter/FilterTest.java |  14 +-
 .../graph/traversal/step/filter/HasNotTest.java |  16 +-
 .../graph/traversal/step/filter/HasTest.java    |  30 +--
 .../graph/traversal/step/filter/IsTest.java     |  16 +-
 .../graph/traversal/step/filter/OrTest.java     |  24 +-
 .../graph/traversal/step/filter/RangeTest.java  |  14 +-
 .../graph/traversal/step/filter/RetainTest.java |  12 +-
 .../graph/traversal/step/filter/SampleTest.java |  16 +-
 .../traversal/step/filter/SimplePathTest.java   |  16 +-
 .../graph/traversal/step/filter/WhereTest.java  |  16 +-
 .../graph/traversal/step/map/BackTest.java      |  16 +-
 .../graph/traversal/step/map/CoalesceTest.java  |  22 +-
 .../graph/traversal/step/map/CountTest.java     |  16 +-
 .../graph/traversal/step/map/FoldTest.java      |  14 +-
 .../graph/traversal/step/map/MapTest.java       |  12 +-
 .../graph/traversal/step/map/MatchTest.java     |  44 ++--
 .../graph/traversal/step/map/MaxTest.java       |  14 +-
 .../graph/traversal/step/map/MeanTest.java      |  12 +-
 .../graph/traversal/step/map/MinTest.java       |  14 +-
 .../graph/traversal/step/map/OrderTest.java     |  20 +-
 .../graph/traversal/step/map/PathTest.java      |  16 +-
 .../traversal/step/map/PropertiesTest.java      |  12 +-
 .../graph/traversal/step/map/SelectTest.java    |  18 +-
 .../graph/traversal/step/map/UnfoldTest.java    |  16 +-
 .../graph/traversal/step/map/ValueMapTest.java  |  12 +-
 .../graph/traversal/step/map/VertexTest.java    |  24 +-
 .../traversal/step/sideEffect/AddEdgeTest.java  |  18 +-
 .../step/sideEffect/AggregateTest.java          |  18 +-
 .../step/sideEffect/GroupCountTest.java         |  14 +-
 .../traversal/step/sideEffect/GroupTest.java    |  14 +-
 .../traversal/step/sideEffect/InjectTest.java   |  16 +-
 .../traversal/step/sideEffect/ProfileTest.java  |  26 +--
 .../traversal/step/sideEffect/SackTest.java     |  20 +-
 .../step/sideEffect/SideEffectCapTest.java      |  16 +-
 .../step/sideEffect/SideEffectTest.java         |  12 +-
 .../traversal/step/sideEffect/StoreTest.java    |  22 +-
 .../traversal/step/sideEffect/SubgraphTest.java |  24 +-
 .../traversal/step/sideEffect/TreeTest.java     |  18 +-
 .../step/util/TraversalSideEffectsTest.java     |  12 +-
 .../strategy/RangeByIsCountStrategyTest.java    |  26 +--
 .../TraversalVerificationStrategyTest.java      |  12 +-
 .../process/traversal/CoreTraversalTest.java    |  34 +--
 .../process/traversal/DefaultTraversalTest.java |  10 +-
 .../gremlin/process/util/PathTest.java          |  14 +-
 .../tinkerpop/gremlin/structure/BatchTest.java  |  22 +-
 .../tinkerpop/gremlin/structure/EdgeTest.java   |  18 +-
 .../gremlin/structure/FeatureSupportTest.java   |  58 ++---
 .../structure/GraphConstructionTest.java        |  14 +-
 .../structure/GraphReadPerformanceTest.java     |  10 +-
 .../tinkerpop/gremlin/structure/GraphTest.java  |  28 +--
 .../structure/GraphWritePerformanceTest.java    |  14 +-
 .../tinkerpop/gremlin/structure/IoTest.java     |  62 +++---
 .../gremlin/structure/MockSerializable.java     |   2 +-
 .../gremlin/structure/PropertyTest.java         |  38 ++--
 .../gremlin/structure/SerializationTest.java    |  14 +-
 .../structure/StructurePerformanceSuite.java    |  18 +-
 .../structure/StructureStandardSuite.java       |  38 ++--
 .../gremlin/structure/TransactionTest.java      |  22 +-
 .../gremlin/structure/VariablesTest.java        |  26 +--
 .../gremlin/structure/VertexPropertyTest.java   |  18 +-
 .../tinkerpop/gremlin/structure/VertexTest.java |  32 +--
 .../io/graphml/GraphMLResourceAccess.java       |   2 +-
 .../io/graphson/GraphSONResourceAccess.java     |   2 +-
 .../structure/io/kryo/KryoResourceAccess.java   |   2 +-
 .../io/script/ScriptResourceAccess.java         |   4 +-
 .../structure/strategy/IdStrategyTest.java      |  22 +-
 .../strategy/PartitionStrategyTest.java         |  16 +-
 .../strategy/ReadOnlyStrategyTest.java          |  28 +--
 .../strategy/SequenceStrategyTest.java          |  26 +--
 .../structure/strategy/StrategyGraphTest.java   |  36 +--
 .../strategy/SubgraphStrategyTest.java          |  16 +-
 .../util/detached/DetachedEdgeTest.java         |  24 +-
 .../util/detached/DetachedPropertyTest.java     |  20 +-
 .../detached/DetachedVertexPropertyTest.java    |  14 +-
 .../util/detached/DetachedVertexTest.java       |  22 +-
 .../process/TraversalStrategiesTest.java        |   6 +-
 .../traversal/GraphTraversalMethodsTest.java    |  10 +-
 .../step/filter/ConjunctionStepTest.java        |  10 +-
 .../gremlin/process/graph/util/TreeTest.java    |   2 +-
 .../gremlin/process/util/BulkSetTest.java       |   2 +-
 .../process/util/TraversalHelperTest.java       |  28 +--
 .../gremlin/structure/CompareTest.java          |   2 +-
 .../structure/ExceptionCoverageTest.java        |  16 +-
 .../structure/FeaturesConventionTest.java       |   4 +-
 .../gremlin/structure/GraphHiddenTest.java      |   2 +-
 .../structure/io/kryo/KryoMapperTest.java       |   2 +-
 .../structure/util/ElementHelperTest.java       |  16 +-
 .../util/config/YamlConfigurationTest.java      |   2 +-
 .../gremlin/util/function/TriConsumerTest.java  |   2 +-
 .../gremlin/util/function/TriFunctionTest.java  |   2 +-
 hadoop-gremlin/conf/hadoop-graphson.properties  |   8 +-
 hadoop-gremlin/conf/hadoop-kryo.properties      |  10 +-
 hadoop-gremlin/pom.xml                          |  12 +-
 .../hadoop/groovy/plugin/HadoopLoader.groovy    |  16 +-
 .../tinkerpop/gremlin/hadoop/Constants.java     |   4 +-
 .../groovy/plugin/HadoopGremlinPlugin.java      |  36 +--
 .../groovy/plugin/HadoopRemoteAcceptor.java     |  22 +-
 .../hadoop/process/computer/HadoopCombine.java  |   8 +-
 .../hadoop/process/computer/HadoopMap.java      |  10 +-
 .../hadoop/process/computer/HadoopReduce.java   |   8 +-
 .../computer/example/TraversalSupplier1.java    |   6 +-
 .../computer/example/TraversalSupplier2.java    |   6 +-
 .../computer/example/TraversalSupplier3.java    |   6 +-
 .../process/computer/giraph/EmptyOutEdges.java  |   2 +-
 .../computer/giraph/GiraphComputeVertex.java    |  42 ++--
 .../computer/giraph/GiraphGraphComputer.java    |  40 ++--
 .../process/computer/giraph/GiraphMemory.java   |  18 +-
 .../computer/giraph/GiraphMessageCombiner.java  |  10 +-
 .../computer/giraph/GiraphMessenger.java        |  24 +-
 .../computer/giraph/GiraphWorkerContext.java    |  10 +-
 .../computer/giraph/MemoryAggregator.java       |   2 +-
 .../process/computer/giraph/RuleWritable.java   |   4 +-
 .../giraph/io/GiraphVertexInputFormat.java      |   6 +-
 .../giraph/io/GiraphVertexOutputFormat.java     |   6 +-
 .../computer/giraph/io/GiraphVertexReader.java  |   6 +-
 .../computer/giraph/io/GiraphVertexWriter.java  |   6 +-
 .../mapreduce/MapReduceGraphComputer.java       |   2 +-
 .../process/computer/util/MapReduceHelper.java  |  26 +--
 .../process/computer/util/MemoryMapReduce.java  |  22 +-
 .../strategy/HadoopElementStepStrategy.java     |  26 +--
 .../hadoop/structure/HadoopConfiguration.java   |   8 +-
 .../gremlin/hadoop/structure/HadoopEdge.java    |  14 +-
 .../gremlin/hadoop/structure/HadoopElement.java |  12 +-
 .../gremlin/hadoop/structure/HadoopGraph.java   |  70 +++---
 .../hadoop/structure/HadoopGraphVariables.java  |   8 +-
 .../hadoop/structure/HadoopProperty.java        |   8 +-
 .../gremlin/hadoop/structure/HadoopVertex.java  |  16 +-
 .../hadoop/structure/HadoopVertexProperty.java  |  18 +-
 .../hadoop/structure/hdfs/HDFSTools.java        |   2 +-
 .../structure/hdfs/HadoopEdgeIterator.java      |  14 +-
 .../structure/hdfs/HadoopElementIterator.java   |  12 +-
 .../structure/hdfs/HadoopVertexIterator.java    |  12 +-
 .../hadoop/structure/hdfs/HiddenFileFilter.java |   2 +-
 .../hadoop/structure/hdfs/TextIterator.java     |   4 +-
 .../structure/io/CommonFileOutputFormat.java    |   2 +-
 .../hadoop/structure/io/ObjectWritable.java     |   4 +-
 .../structure/io/ObjectWritableComparator.java  |   6 +-
 .../structure/io/ObjectWritableIterator.java    |   8 +-
 .../hadoop/structure/io/VertexWritable.java     |  20 +-
 .../io/graphson/GraphSONInputFormat.java        |   4 +-
 .../io/graphson/GraphSONOutputFormat.java       |   6 +-
 .../io/graphson/GraphSONRecordReader.java       |  20 +-
 .../io/graphson/GraphSONRecordWriter.java       |   8 +-
 .../structure/io/kryo/KryoInputFormat.java      |   4 +-
 .../structure/io/kryo/KryoOutputFormat.java     |   6 +-
 .../structure/io/kryo/KryoRecordReader.java     |   6 +-
 .../structure/io/kryo/KryoRecordWriter.java     |   8 +-
 .../structure/io/kryo/VertexStreamIterator.java |  22 +-
 .../structure/io/script/ScriptInputFormat.java  |   6 +-
 .../structure/io/script/ScriptOutputFormat.java |   8 +-
 .../structure/io/script/ScriptRecordReader.java |  20 +-
 .../structure/io/script/ScriptRecordWriter.java |   8 +-
 .../gremlin/hadoop/structure/util/ConfUtil.java |   2 +-
 .../hadoop/structure/util/HadoopHelper.java     |   6 +-
 .../services/javax.script.ScriptEngineFactory   |   2 +-
 ...inkerpop.gremlin.groovy.plugin.GremlinPlugin |   2 +-
 .../gremlin/hadoop/HadoopGraphProvider.java     |  38 ++--
 ...HadoopGraphProcessComputerIntegrateTest.java |   8 +-
 .../process/HadoopGraphProcessStandardTest.java |   8 +-
 ...GraphGroovyProcessComputerIntegrateTest.java |  10 +-
 .../HadoopGraphGroovyProcessStandardTest.java   |  10 +-
 .../io/HadoopGraphStructureStandardTest.java    |   8 +-
 .../GraphSONRecordReaderWriterTest.java         |  10 +-
 .../io/graphson/VertexStreamIteratorTest.java   |  14 +-
 .../io/kryo/KryoRecordReaderWriterTest.java     |  10 +-
 .../io/script/ScriptRecordReaderWriterTest.java |  12 +-
 neo4j-gremlin/pom.xml                           |  10 +-
 .../neo4j/groovy/plugin/Neo4jGremlinPlugin.java |  12 +-
 .../step/sideEffect/Neo4jGraphStep.java         |  38 ++--
 .../step/util/Neo4jCypherIterator.java          |   8 +-
 .../strategy/Neo4jGraphStepStrategy.java        |  18 +-
 .../gremlin/neo4j/structure/Neo4jEdge.java      |  18 +-
 .../gremlin/neo4j/structure/Neo4jElement.java   |  14 +-
 .../gremlin/neo4j/structure/Neo4jGraph.java     |  40 ++--
 .../neo4j/structure/Neo4jGraphVariables.java    |   8 +-
 .../gremlin/neo4j/structure/Neo4jHelper.java    |   4 +-
 .../gremlin/neo4j/structure/Neo4jProperty.java  |  12 +-
 .../gremlin/neo4j/structure/Neo4jVertex.java    |  28 +--
 .../neo4j/structure/Neo4jVertexProperty.java    |  24 +-
 ...inkerpop.gremlin.groovy.plugin.GremlinPlugin |   2 +-
 .../neo4j/AbstractNeo4jGraphProvider.java       |  22 +-
 .../gremlin/neo4j/BaseNeo4jGraphTest.java       |   4 +-
 .../neo4j/DefaultNeo4jGraphProvider.java        |   8 +-
 .../NoMetaMultiPropertyNeo4jGraphProvider.java  |   6 +-
 .../neo4j/process/Neo4jCypherStartTest.java     |   8 +-
 .../process/Neo4jGraphProcessStandardTest.java  |   8 +-
 .../Neo4jGraphGroovyProcessStandardTest.java    |  10 +-
 .../Neo4jGraphStructureStandardTest.java        |   6 +-
 .../gremlin/neo4j/structure/Neo4jGraphTest.java |  22 +-
 ...eo4jGraphStructureStandardIntegrateTest.java |   6 +-
 pom.xml                                         |  24 +-
 tinkergraph-gremlin/pom.xml                     |  14 +-
 .../groovy/plugin/TinkerGraphGremlinPlugin.java |  16 +-
 .../process/computer/TinkerComputerResult.java  |  10 +-
 .../process/computer/TinkerGraphComputer.java   |  26 +--
 .../process/computer/TinkerGraphView.java       |  22 +-
 .../process/computer/TinkerMapEmitter.java      |   6 +-
 .../process/computer/TinkerMemory.java          |  16 +-
 .../process/computer/TinkerMessageBoard.java    |   4 +-
 .../process/computer/TinkerMessenger.java       |  24 +-
 .../process/computer/TinkerReduceEmitter.java   |   6 +-
 .../process/computer/TinkerWorkerPool.java      |   6 +-
 .../traversal/sideEffect/TinkerGraphStep.java   |  20 +-
 .../strategy/TinkerElementStepStrategy.java     |  24 +-
 .../strategy/TinkerGraphStepStrategy.java       |  20 +-
 .../tinkergraph/structure/TinkerEdge.java       |  22 +-
 .../tinkergraph/structure/TinkerElement.java    |  12 +-
 .../tinkergraph/structure/TinkerFactory.java    |  20 +-
 .../tinkergraph/structure/TinkerGraph.java      |  48 ++--
 .../structure/TinkerGraphVariables.java         |   8 +-
 .../tinkergraph/structure/TinkerHelper.java     |  20 +-
 .../tinkergraph/structure/TinkerIndex.java      |  10 +-
 .../tinkergraph/structure/TinkerProperty.java   |  12 +-
 .../tinkergraph/structure/TinkerVertex.java     |  22 +-
 .../structure/TinkerVertexProperty.java         |  12 +-
 ...inkerpop.gremlin.groovy.plugin.GremlinPlugin |   2 +-
 .../structure/GroovyTinkerGraphTest.groovy      |  10 +-
 .../tinkergraph/TinkerGraphGraphProvider.java   |  20 +-
 .../process/TinkerGraphProcessComputerTest.java |   8 +-
 .../TinkerGraphProcessPerformanceTest.java      |  10 +-
 .../process/TinkerGraphProcessStandardTest.java |   8 +-
 .../TinkerGraphGroovyProcessComputerTest.java   |  12 +-
 .../TinkerGraphGroovyProcessStandardTest.java   |  12 +-
 .../TinkerGraphStructurePerformanceTest.java    |   8 +-
 .../TinkerGraphStructureStandardTest.java       |   6 +-
 .../tinkergraph/structure/TinkerGraphTest.java  |  38 ++--
 ...nkerGraphGroovyEnvironmentIntegrateTest.java |  12 +-
 ...erGraphGroovyEnvironmentPerformanceTest.java |  12 +-
 .../TinkerGraphGroovyEnvironmentTest.java       |  12 +-
 884 files changed, 5500 insertions(+), 5500 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/bin/bump.sh
----------------------------------------------------------------------
diff --git a/bin/bump.sh b/bin/bump.sh
index a5dea43..2d9614c 100755
--- a/bin/bump.sh
+++ b/bin/bump.sh
@@ -34,7 +34,7 @@ pushd "$PROJECT_DIR" > /dev/null
 
 # update pom.xml
 for pom in $(find . -name pom.xml); do
-  cat "$pom" | grep -n -A2 -B2 '<groupId>com.tinkerpop</groupId>' \
+  cat "$pom" | grep -n -A2 -B2 '<groupId>org.apache.tinkerpop</groupId>' \
              | grep -A2 -B2 '<artifactId>tinkerpop</artifactId>'  \
              | grep '<version>' | cut -f1 -d '-' | xargs -n1 -I{} sed -i.bak "{}s@>.*<@>${VERSION}<@" "$pom" && rm -f "${pom}.bak"
 done

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/bin/clean-grapes.sh
----------------------------------------------------------------------
diff --git a/docs/preprocessor/processor.groovy b/docs/preprocessor/processor.groovy
index c05f498..8c383cc 100644
--- a/docs/preprocessor/processor.groovy
+++ b/docs/preprocessor/processor.groovy
@@ -1,9 +1,9 @@
 /**
  * @author Daniel Kuppitz (http://gremlin.guru)
  */
-import com.tinkerpop.gremlin.process.computer.util.ScriptEngineCache
-import com.tinkerpop.gremlin.tinkergraph.structure.TinkerFactory
-import com.tinkerpop.gremlin.tinkergraph.structure.TinkerGraph
+import org.apache.tinkerpop.gremlin.process.computer.util.ScriptEngineCache
+import org.apache.tinkerpop.gremlin.tinkergraph.structure.TinkerFactory
+import org.apache.tinkerpop.gremlin.tinkergraph.structure.TinkerGraph
 
 import javax.script.ScriptContext
 
@@ -14,13 +14,13 @@ def STATEMENT_PREFIX = "gremlin> "
 def STATEMENT_CONTINUATION_PREFIX = "         "
 
 def header = """
-    import com.tinkerpop.gremlin.process.graph.traversal.strategy.*
-    import com.tinkerpop.gremlin.tinkergraph.structure.TinkerFactory.SocialTraversal
-    import com.tinkerpop.gremlin.tinkergraph.structure.*
+    import org.apache.tinkerpop.gremlin.process.graph.traversal.strategy.*
+    import org.apache.tinkerpop.gremlin.tinkergraph.structure.TinkerFactory.SocialTraversal
+    import org.apache.tinkerpop.gremlin.tinkergraph.structure.*
     import static java.util.Comparator.*
 """
 
-def imports = new com.tinkerpop.gremlin.console.ConsoleImportCustomizerProvider()
+def imports = new org.apache.tinkerpop.gremlin.console.ConsoleImportCustomizerProvider()
 def skipNextRead = false
 def inCodeSection = false
 def engine

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/docs/src/gremlin-applications.asciidoc
----------------------------------------------------------------------
diff --git a/docs/src/gremlin-applications.asciidoc b/docs/src/gremlin-applications.asciidoc
index c6b5c4a..70639c1 100644
--- a/docs/src/gremlin-applications.asciidoc
+++ b/docs/src/gremlin-applications.asciidoc
@@ -120,8 +120,8 @@ gremlin> :plugin list  <1>
 ==>tinkerpop.tinkergraph[active]
 gremlin> :plugin use tinkerpop.sugar  <2>
 ==>tinkerpop.sugar activated
-gremlin> :install com.tinkerpop neo4j-gremlin x.y.z  <3>
-==>loaded: [com.tinkerpop, neo4j-gremlin, x.y.z]
+gremlin> :install org.apache.tinkerpop neo4j-gremlin x.y.z  <3>
+==>loaded: [org.apache.tinkerpop, neo4j-gremlin, x.y.z]
 gremlin> :plugin list <4>
 ==>tinkerpop.server[active]
 ==>tinkerpop.gephi
@@ -182,9 +182,9 @@ $ bin/gremlin-server.sh conf/gremlin-server-modern.yaml
 -----oOOo-(3)-oOOo-----
 
 [INFO] GremlinServer - Configuring Gremlin Server from conf/gremlin-server-modern.yaml
-[INFO] MetricManager - Configured Metrics Slf4jReporter configured with interval=180000ms and loggerName=com.tinkerpop.gremlin.server.Settings$Slf4jReporterMetrics
-[INFO] GremlinServer$WebSocketServerInitializer - Configured application/vnd.gremlin-v1.0+kryo with com.tinkerpop.gremlin.driver.ser.KryoMessageSerializerV1d0
-[INFO] GremlinServer$WebSocketServerInitializer - Configured application/vnd.gremlin-v1.0+kryo-stringd with com.tinkerpop.gremlin.driver.ser.KryoMessageSerializerV1d0
+[INFO] MetricManager - Configured Metrics Slf4jReporter configured with interval=180000ms and loggerName=org.apache.tinkerpop.gremlin.server.Settings$Slf4jReporterMetrics
+[INFO] GremlinServer$WebSocketServerInitializer - Configured application/vnd.gremlin-v1.0+kryo with org.apache.tinkerpop.gremlin.driver.ser.KryoMessageSerializerV1d0
+[INFO] GremlinServer$WebSocketServerInitializer - Configured application/vnd.gremlin-v1.0+kryo-stringd with org.apache.tinkerpop.gremlin.driver.ser.KryoMessageSerializerV1d0
 [INFO] Graphs - Graph [g] was successfully configured via [config/tinkergraph-empty.properties].
 [INFO] GremlinExecutor - Getting dependencies for [[org.apache.commons, commons-math3, 3.2]]
 [INFO] GremlinExecutor - Initialized gremlin-groovy ScriptEngine with scripts/generate-modern.groovy
@@ -294,7 +294,7 @@ Connecting via Java
 [source,xml]
 ----
 <dependency>
-   <groupId>com.tinkerpop</groupId>
+   <groupId>org.apache.tinkerpop</groupId>
    <artifactId>gremlin-driver</artifactId>
    <version>x.y.z</version>
 </dependency>
@@ -341,12 +341,12 @@ client.submit("[1,2,3,x]", params); <5>
 Connecting via REST
 ~~~~~~~~~~~~~~~~~~~
 
-image:gremlin-rexster.png[width=225,float=left] While the default behavior for Gremlin Server is to provide a WebSockets-based connection, it can also be configured to support link:http://en.wikipedia.org/wiki/Representational_state_transfer[REST].  The REST endpoint provides for a communication protocol familiar to most developers, with a wide support of programming languages, tools and libraries for accessing it.  As a result, REST provides a fast way to get started with Gremlin Server.   It also may represent an easier upgrade path from link:http://rexster.tinkerpop.com/[Rexster] as the API for the endpoint is very similar to Rexster's link:https://github.com/tinkerpop/rexster/wiki/Gremlin-Extension[Gremlin Extension].
+image:gremlin-rexster.png[width=225,float=left] While the default behavior for Gremlin Server is to provide a WebSockets-based connection, it can also be configured to support link:http://en.wikipedia.org/wiki/Representational_state_transfer[REST].  The REST endpoint provides for a communication protocol familiar to most developers, with a wide support of programming languages, tools and libraries for accessing it.  As a result, REST provides a fast way to get started with Gremlin Server.   It also may represent an easier upgrade path from link:http://rexster.tinkerpop.com/[Rexster] as the API for the endpoint is very similar to Rexster's link:https://github.org/apache/tinkerpop/rexster/wiki/Gremlin-Extension[Gremlin Extension].
 
 Gremlin Server provides for a single REST endpoint - a Gremlin evaluator - which allows the submission of a Gremlin script as a request.  For each request, it returns a response containing the serialized results of that script.  To enable this endpoint, Gremlin Server needs to be configured with the `HttpChannelizer`, which replaces the default `WebSocketChannelizer`, in the configuration file:
 
 [source,yaml]
-channelizer: com.tinkerpop.gremlin.server.channel.HttpChannelizer
+channelizer: org.apache.tinkerpop.gremlin.server.channel.HttpChannelizer
 
 This setting is already configured in the `gremlin-server-rest-modern.yaml` file that is packaged with the Gremlin Server distribution.  To utilize it, start Gremlin Server as follows:
 
@@ -413,7 +413,7 @@ The `gremlin-server.sh` file also serves a second purpose.  It can be used to "i
 
 [source,text]
 ----
-bin/gremlin-server.sh -i com.tinkerpop neo4j-gremlin x.y.z
+bin/gremlin-server.sh -i org.apache.tinkerpop neo4j-gremlin x.y.z
 ----
 
 This command will "grab" the appropriate dependencies and copy them to the `ext` directory of Gremlin Server, which will then allow them to be "used" the next time the server is started.  To uninstall dependencies, simply delete them from the `ext` directory.
@@ -557,7 +557,7 @@ Gremlin Server is capable of streaming results such that additional responses wi
  "requestId":"1d6d02bd-8e56-421d-9438-3bd6d0079ff1",
  "status":{"code":299,"attributes":{},"message":""}}
 
-The `299` code signifies stream termination which means that all processing for the request `1d6d02bd-8e56-421d-9438-3bd6d0079ff1` is complete.  Please see the link:http://www.tinkerpop.com/javadocs/current/com/tinkerpop/gremlin/driver/message/ResultCode.html[javadoc] for more information on the various `code` values that are available.
+The `299` code signifies stream termination which means that all processing for the request `1d6d02bd-8e56-421d-9438-3bd6d0079ff1` is complete.  Please see the link:http://www.tinkerpop.com/javadocs/current/org/apache/tinkerpop/gremlin/driver/message/ResultCode.html[javadoc] for more information on the various `code` values that are available.
 
 OpProcessors Arguments
 ^^^^^^^^^^^^^^^^^^^^^^
@@ -637,29 +637,29 @@ Plugins provide a way to expand the features of Gremlin Console and Gremlin Serv
 
 [source,java]
 ----
-include::{basedir}/gremlin-groovy/src/main/java/com/tinkerpop/gremlin/groovy/plugin/GremlinPlugin.java[]
+include::{basedir}/gremlin-groovy/src/main/java/org/apache/tinkerpop/gremlin/groovy/plugin/GremlinPlugin.java[]
 ----
 
 The most simple plugin and the one most commonly implemented will likely be one that just provides a list of classes to import to the Gremlin Console.  This type of plugin is the easiest way for implementers of the TinkerPop Structure and Process APIs to make their implementations available to users.  The Neo4j implementation currently maintained by TinkerPop has just such a plugin:
 
 [source,java]
 ----
-include::{basedir}/neo4j-gremlin/src/main/java/com/tinkerpop/gremlin/neo4j/groovy/plugin/Neo4jGremlinPlugin.java[]
+include::{basedir}/neo4j-gremlin/src/main/java/org/apache/tinkerpop/gremlin/neo4j/groovy/plugin/Neo4jGremlinPlugin.java[]
 ----
 
 Note that the plugin provides a unique name for the plugin which follows a namespaced pattern as _namespace_._plugin-name_ (e.g. "tinkerpop.hadoop" - "tinkerpop" is the reserved namespace for TinkerPop maintained plugins). To make Neo4j classes available to the Console, the `PluginAcceptor` is given a `Set` of imports to provide to the plugin host.  The `PluginAcceptor` essentially behaves as an abstraction to the "host" that is handling the `GremlinPlugin`.  `GremlinPlugin` implementations maybe hosted by the Console as well as the `ScriptEngine` in Gremlin Server.  Obviously, registering new commands and other operations that are specific to the Groovy Shell don't make sense there.  Write the code for the plugin defensively by checking the `GremlinPlugin.env` key in the `PluginAcceptor.environment()` to understand which environment the plugin is being used in.
 
-There is one other step to follow to ensure that the `GremlinPlugin` is visible to its hosts.  `GremlinPlugin` implementations are loaded via link:http://docs.oracle.com/javase/8/docs/api/java/util/ServiceLoader.html[ServiceLoader] and therefore need a resource file added to the jar file where the plugin exists.  Add a file called `com.tinkerpop.gremlin.groovy.plugin.GremlinPlugin` to `META-INF.services`.  In the case of the Neo4j plugin above, that file will have this line in it:
+There is one other step to follow to ensure that the `GremlinPlugin` is visible to its hosts.  `GremlinPlugin` implementations are loaded via link:http://docs.oracle.com/javase/8/docs/api/java/util/ServiceLoader.html[ServiceLoader] and therefore need a resource file added to the jar file where the plugin exists.  Add a file called `org.apache.tinkerpop.gremlin.groovy.plugin.GremlinPlugin` to `META-INF.services`.  In the case of the Neo4j plugin above, that file will have this line in it:
 
 [source,java]
 ----
-include::{basedir}/neo4j-gremlin/src/main/resources/META-INF/services/com.tinkerpop.gremlin.groovy.plugin.GremlinPlugin[]
+include::{basedir}/neo4j-gremlin/src/main/resources/META-INF/services/org.apache.tinkerpop.gremlin.groovy.plugin.GremlinPlugin[]
 ----
 
 Once the plugin is packaged, there are two ways to test it out:
 
 . Copy the jar and its dependencies to the Gremlin Console path and start it.
-. Start Gremlin Console and try the `:install` command.  For the case of the Neo4j plugin, it would look like this: `:install com.tinkerpop neo4j-gremlin x.y.z`.
+. Start Gremlin Console and try the `:install` command.  For the case of the Neo4j plugin, it would look like this: `:install org.apache.tinkerpop neo4j-gremlin x.y.z`.
 
 In either case, once one of these two approaches is taken, the jars and their dependencies are available to the Console.  The next step is to "activate" the plugin by doing `:plugin use neo4j`, where "neo4j" refers to the name of the plugin to activate.
 
@@ -679,7 +679,7 @@ TIP: Consider binding the plugin's minor version to the TinkerPop minor version
 
 [source,java]
 ----
-include::{basedir}/gremlin-groovy/src/main/java/com/tinkerpop/gremlin/groovy/plugin/RemoteAcceptor.java[]
+include::{basedir}/gremlin-groovy/src/main/java/org/apache/tinkerpop/gremlin/groovy/plugin/RemoteAcceptor.java[]
 ----
 
 The `RemoteAcceptor` implementation ties to a `GremlinPlugin` and will only be executed when in use with the Gremlin Console plugin host.  Simply instantiate and return a `RemoteAcceptor` in the `GremlinPlugin.remoteAcceptor()` method of the plugin implementation.  Generally speaking, each call to `remoteAcceptor()` should produce a new instance of a `RemoteAcceptor`.  It will likely be necessary that you provide context from the `GremlinPlugin` to the `RemoteAcceptor` plugin.  For example, the `RemoteAcceptor` implementation might require an instance of `Groovysh` to provide a way to dynamically evaluate a script provided to it so that it can process the results in a different way.
@@ -965,10 +965,10 @@ Flat:
 
  %    cumulative   self            self     total    self    total   self    total                                                                              
 time   seconds    seconds  calls  ms/call  ms/call  min ms  min ms  max ms  max ms  name                                                                        
-61.8        0.02     0.02      1    22.60    22.60   22.60   22.60   22.60   22.60  com.tinkerpop.gremlin.tinkergraph.process.graph.TinkerGraphTraversal.iterate
-23.5        0.03     0.00      1     8.62     8.62    8.62    8.62    8.62    8.62  com.tinkerpop.gremlin.tinkergraph.structure.TinkerGraph.V                   
+61.8        0.02     0.02      1    22.60    22.60   22.60   22.60   22.60   22.60  org.apache.tinkerpop.gremlin.tinkergraph.process.graph.TinkerGraphTraversal.iterate
+23.5        0.03     0.00      1     8.62     8.62    8.62    8.62    8.62    8.62  org.apache.tinkerpop.gremlin.tinkergraph.structure.TinkerGraph.V                   
 13.4        0.03     0.00      1     4.93    36.57    4.93   36.57    4.93   36.57  groovysh_evaluate$_run_closure1.doCall                                      
- 1.0        0.03     0.00      1     0.38     0.40    0.38    0.40    0.38    0.40  com.tinkerpop.gremlin.groovy.loaders.GremlinLoader.isStep                   
+ 1.0        0.03     0.00      1     0.38     0.40    0.38    0.40    0.38    0.40  org.apache.tinkerpop.gremlin.groovy.loaders.GremlinLoader.isStep                   
  0.0        0.03     0.00      1     0.01     0.01    0.01    0.01    0.01    0.01  java.util.HashSet.contains                                                  
 
 Call graph:
@@ -976,21 +976,21 @@ Call graph:
 index  % time  self  children  calls  name                                                                                
                0.00      0.03    1/1      <spontaneous>                                                                   
 [1]     100.0  0.00      0.03      1  groovysh_evaluate$_run_closure1.doCall [1]                                          
-               0.02      0.00    1/1      com.tinkerpop.gremlin.tinkergraph.process.graph.TinkerGraphTraversal.iterate [2]
-               0.00      0.00    1/1      com.tinkerpop.gremlin.tinkergraph.structure.TinkerGraph.V [3]                   
-               0.00      0.00    1/1      com.tinkerpop.gremlin.groovy.loaders.GremlinLoader.isStep [4]                   
+               0.02      0.00    1/1      org.apache.tinkerpop.gremlin.tinkergraph.process.graph.TinkerGraphTraversal.iterate [2]
+               0.00      0.00    1/1      org.apache.tinkerpop.gremlin.tinkergraph.structure.TinkerGraph.V [3]                   
+               0.00      0.00    1/1      org.apache.tinkerpop.gremlin.groovy.loaders.GremlinLoader.isStep [4]                   
 --------------------------------------------------------------------------------------------------------------------------
                0.02      0.00    1/1      groovysh_evaluate$_run_closure1.doCall [1]                                      
-[2]      61.8  0.02      0.00      1  com.tinkerpop.gremlin.tinkergraph.process.graph.TinkerGraphTraversal.iterate [2]    
+[2]      61.8  0.02      0.00      1  org.apache.tinkerpop.gremlin.tinkergraph.process.graph.TinkerGraphTraversal.iterate [2]    
 --------------------------------------------------------------------------------------------------------------------------
                0.00      0.00    1/1      groovysh_evaluate$_run_closure1.doCall [1]                                      
-[3]      23.5  0.00      0.00      1  com.tinkerpop.gremlin.tinkergraph.structure.TinkerGraph.V [3]                       
+[3]      23.5  0.00      0.00      1  org.apache.tinkerpop.gremlin.tinkergraph.structure.TinkerGraph.V [3]                       
 --------------------------------------------------------------------------------------------------------------------------
                0.00      0.00    1/1      groovysh_evaluate$_run_closure1.doCall [1]                                      
-[4]       1.1  0.00      0.00      1  com.tinkerpop.gremlin.groovy.loaders.GremlinLoader.isStep [4]                       
+[4]       1.1  0.00      0.00      1  org.apache.tinkerpop.gremlin.groovy.loaders.GremlinLoader.isStep [4]                       
                0.00      0.00    1/1      java.util.HashSet.contains [5]                                                  
 --------------------------------------------------------------------------------------------------------------------------
-               0.00      0.00    1/1      com.tinkerpop.gremlin.groovy.loaders.GremlinLoader.isStep [4]                   
+               0.00      0.00    1/1      org.apache.tinkerpop.gremlin.groovy.loaders.GremlinLoader.isStep [4]                   
 [5]       0.0  0.00      0.00      1  java.util.HashSet.contains [5]                                                      
 --------------------------------------------------------------------------------------------------------------------------
 ==>null
@@ -1006,18 +1006,18 @@ A good implementation of the Gremlin APIs will validate their features against t
 ----
 gremlin> describeGraph(HadoopGraph)
 ==>
-IMPLEMENTATION - com.tinkerpop.gremlin.hadoop.structure.HadoopGraph
+IMPLEMENTATION - org.apache.tinkerpop.gremlin.hadoop.structure.HadoopGraph
 TINKERPOP TEST SUITE
 - Compliant with (4 of 8 suites)
-> com.tinkerpop.gremlin.process.ProcessStandardSuite
-> com.tinkerpop.gremlin.process.ProcessComputerSuite
-> com.tinkerpop.gremlin.process.GroovyProcessStandardSuite
-> com.tinkerpop.gremlin.process.GroovyProcessComputerSuite
+> org.apache.tinkerpop.gremlin.process.ProcessStandardSuite
+> org.apache.tinkerpop.gremlin.process.ProcessComputerSuite
+> org.apache.tinkerpop.gremlin.process.GroovyProcessStandardSuite
+> org.apache.tinkerpop.gremlin.process.GroovyProcessComputerSuite
 - Opts out of 12 individual tests
-> com.tinkerpop.gremlin.process.graph.step.map.MatchTest$StandardTest#g_V_matchXa_hasXname_GarciaX__a_0writtenBy_b__a_0sungBy_bX
+> org.apache.tinkerpop.gremlin.process.graph.step.map.MatchTest$StandardTest#g_V_matchXa_hasXname_GarciaX__a_0writtenBy_b__a_0sungBy_bX
 	"Hadoop-Gremlin is OLAP-oriented and for OLTP operations, linear-scan joins are required. This particular tests takes many minutes to execute."
 ...
-> com.tinkerpop.gremlin.process.graph.step.map.MatchTest$JavaMatchTest#g_V_matchXa_inXsungByX_b__a_inXsungByX_c__b_outXwrittenByX_d__c_outXwrittenByX_e__d_hasXname_George_HarisonX__e_hasXname_Bob_MarleyXX
+> org.apache.tinkerpop.gremlin.process.graph.step.map.MatchTest$JavaMatchTest#g_V_matchXa_inXsungByX_b__a_inXsungByX_c__b_outXwrittenByX_d__c_outXwrittenByX_e__d_hasXname_George_HarisonX__e_hasXname_Bob_MarleyXX
 	"Hadoop-Gremlin is OLAP-oriented and for OLTP operations, linear-scan joins are required. This particular tests takes many minutes to execute."
 
 - NOTE -

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/docs/src/implementations.asciidoc
----------------------------------------------------------------------
diff --git a/docs/src/implementations.asciidoc b/docs/src/implementations.asciidoc
index 500cd83..215a4d9 100644
--- a/docs/src/implementations.asciidoc
+++ b/docs/src/implementations.asciidoc
@@ -220,7 +220,7 @@ Validating with Gremlin-Test
 
 [source,xml]
 <dependency>
-  <groupId>com.tinkerpop</groupId>
+  <groupId>org.apache.tinkerpop</groupId>
   <artifactId>gremlin-test</artifactId>
   <version>x.y.z</version>
 </dependency>
@@ -272,19 +272,19 @@ There are times when there may be a specific test in the suite that the implemen
 @Graph.OptIn(Graph.OptIn.SUITE_PROCESS_STANDARD)
 @Graph.OptIn(Graph.OptIn.SUITE_PROCESS_COMPUTER)
 @Graph.OptOut(
-        test = "com.tinkerpop.gremlin.process.graph.step.map.MatchTest$JavaMatchTest",
+        test = "org.apache.tinkerpop.gremlin.process.graph.step.map.MatchTest$JavaMatchTest",
         method = "g_V_matchXa_hasXname_GarciaX__a_inXwrittenByX_b__a_inXsungByX_bX",
         reason = "Hadoop-Gremlin is OLAP-oriented and for OLTP operations, linear-scan joins are required. This particular tests takes many minutes to execute.")
 @Graph.OptOut(
-        test = "com.tinkerpop.gremlin.process.graph.step.map.MatchTest$JavaMatchTest",
+        test = "org.apache.tinkerpop.gremlin.process.graph.step.map.MatchTest$JavaMatchTest",
         method = "g_V_matchXa_inXsungByX_b__a_inXsungByX_c__b_outXwrittenByX_d__c_outXwrittenByX_e__d_hasXname_George_HarisonX__e_hasXname_Bob_MarleyXX",
         reason = "Hadoop-Gremlin is OLAP-oriented and for OLTP operations, linear-scan joins are required. This particular tests takes many minutes to execute.")
 @Graph.OptOut(
-        test = "com.tinkerpop.gremlin.process.computer.GroovyGraphComputerTest$ComputerTest",
+        test = "org.apache.tinkerpop.gremlin.process.computer.GroovyGraphComputerTest$ComputerTest",
         method = "shouldNotAllowBadMemoryKeys",
         reason = "Hadoop does a hard kill on failure and stops threads which stops test cases. Exception handling semantics are correct though.")
 @Graph.OptOut(
-        test = "com.tinkerpop.gremlin.process.computer.GroovyGraphComputerTest$ComputerTest",
+        test = "org.apache.tinkerpop.gremlin.process.computer.GroovyGraphComputerTest$ComputerTest",
         method = "shouldRequireRegisteringMemoryKeys",
         reason = "Hadoop does a hard kill on failure and stops threads which stops test cases. Exception handling semantics are correct though.")
 public class HadoopGraph implements Graph {
@@ -333,8 +333,8 @@ With the above plugin implementations, users can now download respective binarie
 gremlin> g = Neo4jGraph.open('/tmp/neo4j')
 No such property: Neo4jGraph for class: groovysh_evaluate
 Display stack trace? [yN]
-gremlin> :install com.tinkerpop neo4j-gremlin x.y.z
-==>loaded: [com.tinkerpop, neo4j-gremlin, …]
+gremlin> :install org.apache.tinkerpop neo4j-gremlin x.y.z
+==>loaded: [org.apache.tinkerpop, neo4j-gremlin, …]
 gremlin> :plugin use tinkerpop.neo4j
 ==>tinkerpop.neo4j activated
 gremlin> g = Neo4jGraph.open('/tmp/neo4j')
@@ -356,7 +356,7 @@ TinkerGraph-Gremlin
 [source,xml]
 ----
 <dependency>
-   <groupId>com.tinkerpop</groupId>
+   <groupId>org.apache.tinkerpop</groupId>
    <artifactId>tinkergraph-gremlin</artifactId>
    <version>x.y.z</version>
 </dependency>
@@ -413,7 +413,7 @@ Neo4j-Gremlin
 [source,xml]
 ----
 <dependency>
-   <groupId>com.tinkerpop</groupId>
+   <groupId>org.apache.tinkerpop</groupId>
    <artifactId>neo4j-gremlin</artifactId>
    <version>x.y.z</version>
 </dependency>
@@ -425,8 +425,8 @@ CAUTION: Unless under a commercial agreement with Neo Technology, Neo4j is licen
 
 [source,groovy]
 ----
-gremlin> :install com.tinkerpop neo4j-gremlin x.y.z
-==>loaded: [com.tinkerpop, neo4j-gremlin, x.y.z]
+gremlin> :install org.apache.tinkerpop neo4j-gremlin x.y.z
+==>loaded: [org.apache.tinkerpop, neo4j-gremlin, x.y.z]
 gremlin> :plugin use tinkerpop.neo4j
 ==>tinkerpop.neo4j activated
 gremlin> g = Neo4jGraph.open('/tmp/neo4j')
@@ -437,7 +437,7 @@ For those leveraging Neo4j High Availability, configure `Neo4jGraph` for "HA mod
 
 IMPORTANT: `Neo4jGraph` supports both meta- and multi-properties (see <<_vertex_properties,vertex properties>>). However, these are implemented by making use of "hidden" Neo4j nodes. For example, when a vertex has multiple "name" properties, each property is a new node (multi-properties) which can have properties attached to it (meta-properties). As such, the underlying representation may become difficult to query directly using another graph language such as Cypher. The default setting is to disable multi- and meta-properties. However, if this feature is desired, then it can be activated via `gremlin.neo4j.metaProperties` and `gremlin.neo4j.multiProperties` configurations being set to `true`. Once the configuration is set, it can not be changed for the lifetime of the graph.
 
-TIP: To host Neo4j in Gremlin Server, the dependencies must first be "installed" or otherwise copied to the Gremlin Server path.  The automated method for doing this would be to execute `bin/gremlin-server.sh -i com.tinkerpop neo4j-gremlin x.y.z`.
+TIP: To host Neo4j in Gremlin Server, the dependencies must first be "installed" or otherwise copied to the Gremlin Server path.  The automated method for doing this would be to execute `bin/gremlin-server.sh -i org.apache.tinkerpop neo4j-gremlin x.y.z`.
 
 Indices
 ~~~~~~~
@@ -593,7 +593,7 @@ Hadoop-Gremlin
 [source,xml]
 ----
 <dependency>
-   <groupId>com.tinkerpop</groupId>
+   <groupId>org.apache.tinkerpop</groupId>
    <artifactId>hadoop-gremlin</artifactId>
    <version>x.y.z</version>
 </dependency>
@@ -623,8 +623,8 @@ $ bin/gremlin.sh
 plugin activated: tinkerpop.server
 plugin activated: tinkerpop.utilities
 plugin activated: tinkerpop.tinkergraph
-gremlin> :install com.tinkerpop hadoop-gremlin x.y.z
-==>loaded: [com.tinkerpop, hadoop-gremlin, x.y.z] - restart the console to use [tinkerpop.hadoop]
+gremlin> :install org.apache.tinkerpop hadoop-gremlin x.y.z
+==>loaded: [org.apache.tinkerpop, hadoop-gremlin, x.y.z] - restart the console to use [tinkerpop.hadoop]
 gremlin> :q
 $ bin/gremlin.sh
 
@@ -645,15 +645,15 @@ Properties Files
 `HadoopGraph` makes heavy use of properties files which ultimately get turned into Apache Configurations and Hadoop configurations. The properties file presented below is located at `conf/hadoop-kryo.properties'.
 
 [source,text]
-gremlin.graph=com.tinkerpop.gremlin.hadoop.structure.HadoopGraph
+gremlin.graph=org.apache.tinkerpop.gremlin.hadoop.structure.HadoopGraph
 gremlin.hadoop.inputLocation=tinkerpop-modern-vertices.gio
-gremlin.hadoop.graphInputFormat=com.tinkerpop.gremlin.hadoop.structure.io.kryo.KryoInputFormat
+gremlin.hadoop.graphInputFormat=org.apache.tinkerpop.gremlin.hadoop.structure.io.kryo.KryoInputFormat
 gremlin.hadoop.outputLocation=output
-gremlin.hadoop.graphOutputFormat=com.tinkerpop.gremlin.hadoop.structure.io.kryo.KryoOutputFormat
+gremlin.hadoop.graphOutputFormat=org.apache.tinkerpop.gremlin.hadoop.structure.io.kryo.KryoOutputFormat
 gremlin.hadoop.memoryOutputFormat=org.apache.hadoop.mapreduce.lib.output.SequenceFileOutputFormat
-gremlin.vertexProgram=com.tinkerpop.gremlin.process.computer.traversal.TraversalVertexProgram
+gremlin.vertexProgram=org.apache.tinkerpop.gremlin.process.computer.traversal.TraversalVertexProgram
 gremlin.traversalVertexProgram.traversalSupplier.type=CLASS
-gremlin.traversalVertexProgram.traversalSupplier.object=com.tinkerpop.gremlin.hadoop.process.computer.example.TraversalSupplier1
+gremlin.traversalVertexProgram.traversalSupplier.object=org.apache.tinkerpop.gremlin.hadoop.process.computer.example.TraversalSupplier1
 gremlin.hadoop.jarsInDistributedCache=true
 gremlin.hadoop.deriveMemory=false
 giraph.minWorkers=2
@@ -736,32 +736,32 @@ WARNING: The maximum number of workers can be no larger than the number of map-s
 gremlin> :remote connect tinkerpop.hadoop ../../../hadoop-gremlin/conf/hadoop-kryo.properties
 ==>hadoopgraph[kryoinputformat->kryooutputformat]
 gremlin> :> g.V().count()
-INFO  com.tinkerpop.gremlin.hadoop.process.computer.giraph.GiraphGraphComputer  - HadoopGremlin(Giraph): TraversalVertexProgram[HadoopGraphStep(vertex), CountStep, SideEffectCapStep]
+INFO  org.apache.tinkerpop.gremlin.hadoop.process.computer.giraph.GiraphGraphComputer  - HadoopGremlin(Giraph): TraversalVertexProgram[HadoopGraphStep(vertex), CountStep, SideEffectCapStep]
 INFO  org.apache.hadoop.mapred.JobClient  - Running job: job_201407281259_0037
 INFO  org.apache.hadoop.mapred.JobClient  -  map 0% reduce 0%
 ...
-INFO  com.tinkerpop.gremlin.hadoop.structure.HadoopGraph  - HadoopGremlin: CountMapReduce
+INFO  org.apache.tinkerpop.gremlin.hadoop.structure.HadoopGraph  - HadoopGremlin: CountMapReduce
 INFO  org.apache.hadoop.mapred.JobClient  - Running job: job_201407281259_0038
 INFO  org.apache.hadoop.mapred.JobClient  -  map 0% reduce 0%
 ...
 ==>6
 gremlin> :> g.V().out().out().values('name')
-INFO  com.tinkerpop.gremlin.giraph.process.computer.giraph.GiraphGraphComputer  - HadoopGremlin(Giraph): TraversalVertexProgram[HadoopGraphStep(vertex), VertexStep(OUT), VertexStep(OUT), ElementValueStep(name)]
+INFO  org.apache.tinkerpop.gremlin.giraph.process.computer.giraph.GiraphGraphComputer  - HadoopGremlin(Giraph): TraversalVertexProgram[HadoopGraphStep(vertex), VertexStep(OUT), VertexStep(OUT), ElementValueStep(name)]
 INFO  org.apache.hadoop.mapred.JobClient  - Running job: job_201407281259_0031
 INFO  org.apache.hadoop.mapred.JobClient  -  map 0% reduce 0%
 ...
-INFO  com.tinkerpop.gremlin.hadoop.structure.HadoopGraph  - HadoopGremlin: TraversalResultMapReduce
+INFO  org.apache.tinkerpop.gremlin.hadoop.structure.HadoopGraph  - HadoopGremlin: TraversalResultMapReduce
 INFO  org.apache.hadoop.mapred.JobClient  - Running job: job_201407281259_0032
 INFO  org.apache.hadoop.mapred.JobClient  -  map 0% reduce 0%
 ...
 ==>ripple
 ==>lop
 gremlin> :> g.V().group('a').by{it.value('name')[1]}.by{it.value('name')}
-INFO  com.tinkerpop.gremlin.giraph.process.computer.giraph.GiraphGraphComputer  - HadoopGremlin(Giraph): TraversalVertexProgram[HadoopGraphStep(vertex), GroupByStep@a, SideEffectCapStep(a)]
+INFO  org.apache.tinkerpop.gremlin.giraph.process.computer.giraph.GiraphGraphComputer  - HadoopGremlin(Giraph): TraversalVertexProgram[HadoopGraphStep(vertex), GroupByStep@a, SideEffectCapStep(a)]
 INFO  org.apache.hadoop.mapred.JobClient  - Running job: job_201407281259_0039
 INFO  org.apache.hadoop.mapred.JobClient  -  map 0% reduce 0%
 ...
-INFO  com.tinkerpop.gremlin.hadoop.structure.HadoopGraph  - HadoopGremlin: GroupByMapReduce[a]
+INFO  org.apache.tinkerpop.gremlin.hadoop.structure.HadoopGraph  - HadoopGremlin: GroupByMapReduce[a]
 INFO  org.apache.hadoop.mapred.JobClient  - Running job: job_201407281259_0040
 INFO  org.apache.hadoop.mapred.JobClient  -  map 0% reduce 0%
 ...
@@ -787,7 +787,7 @@ The `TraversalSupplier1` class mentioned in the `hadoop-kryo.properties` file is
 [source,java]
 ----
 // gremlin.traversalVertexProgram.traversalSupplier.type=CLASS
-// gremlin.traversalVertexProgram.traversalSupplier.object=com.tinkerpop.gremlin.hadoop.process.computer.example.TraversalSupplier1
+// gremlin.traversalVertexProgram.traversalSupplier.object=org.apache.tinkerpop.gremlin.hadoop.process.computer.example.TraversalSupplier1
 
 public class TraversalSupplier1 implements SSupplier<Traversal> {
     public Traversal get() {
@@ -859,7 +859,7 @@ $ hadoop fs -copyFromLocal data/tinkerpop-modern-vertices.ldjson tinkerpop-moder
 $ hadoop fs -ls
 Found 2 items
 -rw-r--r--   1 marko supergroup       2356 2014-07-28 13:00 /user/marko/tinkerpop-modern-vertices.ldjson
-$ hadoop jar target/hadoop-gremlin-x.y.z-job.jar com.tinkerpop.gremlin.hadoop.process.computer.giraph.GiraphGraphComputer conf/hadoop-graphson.properties
+$ hadoop jar target/hadoop-gremlin-x.y.z-job.jar org.apache.tinkerpop.gremlin.hadoop.process.computer.giraph.GiraphGraphComputer conf/hadoop-graphson.properties
 14/07/29 12:08:27 INFO giraph.GiraphGraphComputer: HadoopGremlin(Giraph): PageRankVertexProgram[alpha=0.85,iterations=30]
 14/07/29 12:08:28 INFO mapred.JobClient: Running job: job_201407281259_0041
 14/07/29 12:08:29 INFO mapred.JobClient:  map 0% reduce 0%

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/docs/src/intro.asciidoc
----------------------------------------------------------------------
diff --git a/docs/src/intro.asciidoc b/docs/src/intro.asciidoc
index d650774..3c00e21 100644
--- a/docs/src/intro.asciidoc
+++ b/docs/src/intro.asciidoc
@@ -6,7 +6,7 @@ image::graph-computing.png[width=350]
 
 [source,xml]
 <dependency>
-  <groupId>com.tinkerpop</groupId>
+  <groupId>org.apache.tinkerpop</groupId>
   <artifactId>gremlin-core</artifactId>
   <version>x.y.z</version>
 </dependency>
diff --git a/bin/clean-grapes.sh b/bin/clean-grapes.sh
index 3467db2..50b6137 100755
--- a/bin/clean-grapes.sh
+++ b/bin/clean-grapes.sh
@@ -19,7 +19,7 @@
 # under the License.
 #
 
 # This script removes the com.tinkerpop directory from the "grapes" directory. This
 # script assumes that an environment variable of GROOVY_GRAPES is set with the location
 # of the grapes directory.  Otherwise, it will set that value to the standard location
 # of ~/.groovy/grapes which is common for most installations.  Usage:
@@ -30,6 +30,6 @@ if [ -z "${GROOVY_GRAPES:-}" ]; then
     GROOVY_GRAPES=~/.groovy/grapes
 fi
 
-GRAPES_TP="$GROOVY_GRAPES/com.tinkerpop"
+GRAPES_TP="$GROOVY_GRAPES/org.apache.tinkerpop"
 
 rm -rf $GRAPES_TP
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/f4da7f7a/docs/preprocessor/processor.groovy
----------------------------------------------------------------------
@@ -19,7 +19,7 @@
 #
 
-# This script removes the com.tinkerpop directory from the "grapes" directory. This
+# This script removes the org.apache.tinkerpop directory from the "grapes" directory. This
 # script assumes that an environment variable of GROOVY_GRAPES is set with the location
 # of the grapes directory.  Otherwise, it will set that value to the standard location